import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * An example resource schema demonstrating some basic constructs and validation rules.
 *
 * ## Example Usage
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const config = new pulumi.Config();
 * const graphQlApiId = config.require("graphQlApiId");
 * const name = config.require("name");
 * const description = config.require("description");
 * const dataSourceName = config.require("dataSourceName");
 * const functionVersion = config.require("functionVersion");
 * const requestMappingTemplateS3LocationInput = config.require("requestMappingTemplateS3LocationInput");
 * const responseMappingTemplateS3LocationInput = config.require("responseMappingTemplateS3LocationInput");
 * const functionConfiguration = new aws_native.appsync.FunctionConfiguration("functionConfiguration", {
 *     apiId: graphQlApiId,
 *     name: name,
 *     description: description,
 *     functionVersion: functionVersion,
 *     dataSourceName: dataSourceName,
 *     requestMappingTemplateS3Location: requestMappingTemplateS3LocationInput,
 *     responseMappingTemplateS3Location: responseMappingTemplateS3LocationInput,
 * });
 *
 * ```
 */
export declare class FunctionConfiguration extends pulumi.CustomResource {
    /**
     * Get an existing FunctionConfiguration resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): FunctionConfiguration;
    /**
     * Returns true if the given object is an instance of FunctionConfiguration.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is FunctionConfiguration;
    /**
     * The AWS AppSync GraphQL API that you want to attach using this function.
     */
    readonly apiId: pulumi.Output<string>;
    /**
     * The resolver code that contains the request and response functions. When code is used, the runtime is required. The runtime value must be APPSYNC_JS.
     */
    readonly code: pulumi.Output<string | undefined>;
    /**
     * The Amazon S3 endpoint (where the code is located??).
     */
    readonly codeS3Location: pulumi.Output<string | undefined>;
    /**
     * The name of data source this function will attach.
     */
    readonly dataSourceName: pulumi.Output<string>;
    /**
     * The function description.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The ARN for the function generated by the service
     */
    readonly functionArn: pulumi.Output<string>;
    /**
     * The unique identifier for the function generated by the service
     */
    readonly functionId: pulumi.Output<string>;
    /**
     * The version of the request mapping template. Currently, only the 2018-05-29 version of the template is supported.
     */
    readonly functionVersion: pulumi.Output<string | undefined>;
    /**
     * The maximum number of resolver request inputs that will be sent to a single AWS Lambda function in a BatchInvoke operation.
     */
    readonly maxBatchSize: pulumi.Output<number | undefined>;
    /**
     * The name of the function.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The Function request mapping template. Functions support only the 2018-05-29 version of the request mapping template.
     */
    readonly requestMappingTemplate: pulumi.Output<string | undefined>;
    /**
     * Describes a Sync configuration for a resolver. Contains information on which Conflict Detection, as well as Resolution strategy, should be performed when the resolver is invoked.
     */
    readonly requestMappingTemplateS3Location: pulumi.Output<string | undefined>;
    /**
     * The Function response mapping template.
     */
    readonly responseMappingTemplate: pulumi.Output<string | undefined>;
    /**
     * The location of a response mapping template in an Amazon S3 bucket. Use this if you want to provision with a template file in Amazon S3 rather than embedding it in your CloudFormation template.
     */
    readonly responseMappingTemplateS3Location: pulumi.Output<string | undefined>;
    /**
     * Describes a runtime used by an AWS AppSync pipeline resolver or AWS AppSync function. Specifies the name and version of the runtime to use. Note that if a runtime is specified, code must also be specified.
     */
    readonly runtime: pulumi.Output<outputs.appsync.FunctionConfigurationAppSyncRuntime | undefined>;
    /**
     * Describes a Sync configuration for a resolver. Specifies which Conflict Detection strategy and Resolution strategy to use when the resolver is invoked.
     */
    readonly syncConfig: pulumi.Output<outputs.appsync.FunctionConfigurationSyncConfig | undefined>;
    /**
     * Create a FunctionConfiguration resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: FunctionConfigurationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a FunctionConfiguration resource.
 */
export interface FunctionConfigurationArgs {
    /**
     * The AWS AppSync GraphQL API that you want to attach using this function.
     */
    apiId: pulumi.Input<string>;
    /**
     * The resolver code that contains the request and response functions. When code is used, the runtime is required. The runtime value must be APPSYNC_JS.
     */
    code?: pulumi.Input<string>;
    /**
     * The Amazon S3 endpoint (where the code is located??).
     */
    codeS3Location?: pulumi.Input<string>;
    /**
     * The name of data source this function will attach.
     */
    dataSourceName: pulumi.Input<string>;
    /**
     * The function description.
     */
    description?: pulumi.Input<string>;
    /**
     * The version of the request mapping template. Currently, only the 2018-05-29 version of the template is supported.
     */
    functionVersion?: pulumi.Input<string>;
    /**
     * The maximum number of resolver request inputs that will be sent to a single AWS Lambda function in a BatchInvoke operation.
     */
    maxBatchSize?: pulumi.Input<number>;
    /**
     * The name of the function.
     */
    name?: pulumi.Input<string>;
    /**
     * The Function request mapping template. Functions support only the 2018-05-29 version of the request mapping template.
     */
    requestMappingTemplate?: pulumi.Input<string>;
    /**
     * Describes a Sync configuration for a resolver. Contains information on which Conflict Detection, as well as Resolution strategy, should be performed when the resolver is invoked.
     */
    requestMappingTemplateS3Location?: pulumi.Input<string>;
    /**
     * The Function response mapping template.
     */
    responseMappingTemplate?: pulumi.Input<string>;
    /**
     * The location of a response mapping template in an Amazon S3 bucket. Use this if you want to provision with a template file in Amazon S3 rather than embedding it in your CloudFormation template.
     */
    responseMappingTemplateS3Location?: pulumi.Input<string>;
    /**
     * Describes a runtime used by an AWS AppSync pipeline resolver or AWS AppSync function. Specifies the name and version of the runtime to use. Note that if a runtime is specified, code must also be specified.
     */
    runtime?: pulumi.Input<inputs.appsync.FunctionConfigurationAppSyncRuntimeArgs>;
    /**
     * Describes a Sync configuration for a resolver. Specifies which Conflict Detection strategy and Resolution strategy to use when the resolver is invoked.
     */
    syncConfig?: pulumi.Input<inputs.appsync.FunctionConfigurationSyncConfigArgs>;
}
