import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * An example resource schema demonstrating some basic constructs and validation rules.
 */
export declare function getFunctionConfiguration(args: GetFunctionConfigurationArgs, opts?: pulumi.InvokeOptions): Promise<GetFunctionConfigurationResult>;
export interface GetFunctionConfigurationArgs {
    /**
     * The ARN for the function generated by the service
     */
    functionArn: string;
}
export interface GetFunctionConfigurationResult {
    /**
     * The resolver code that contains the request and response functions. When code is used, the runtime is required. The runtime value must be APPSYNC_JS.
     */
    readonly code?: string;
    /**
     * The name of data source this function will attach.
     */
    readonly dataSourceName?: string;
    /**
     * The function description.
     */
    readonly description?: string;
    /**
     * The ARN for the function generated by the service
     */
    readonly functionArn?: string;
    /**
     * The unique identifier for the function generated by the service
     */
    readonly functionId?: string;
    /**
     * The version of the request mapping template. Currently, only the 2018-05-29 version of the template is supported.
     */
    readonly functionVersion?: string;
    /**
     * The maximum number of resolver request inputs that will be sent to a single AWS Lambda function in a BatchInvoke operation.
     */
    readonly maxBatchSize?: number;
    /**
     * The name of the function.
     */
    readonly name?: string;
    /**
     * The Function request mapping template. Functions support only the 2018-05-29 version of the request mapping template.
     */
    readonly requestMappingTemplate?: string;
    /**
     * The Function response mapping template.
     */
    readonly responseMappingTemplate?: string;
    /**
     * Describes a runtime used by an AWS AppSync pipeline resolver or AWS AppSync function. Specifies the name and version of the runtime to use. Note that if a runtime is specified, code must also be specified.
     */
    readonly runtime?: outputs.appsync.FunctionConfigurationAppSyncRuntime;
    /**
     * Describes a Sync configuration for a resolver. Specifies which Conflict Detection strategy and Resolution strategy to use when the resolver is invoked.
     */
    readonly syncConfig?: outputs.appsync.FunctionConfigurationSyncConfig;
}
/**
 * An example resource schema demonstrating some basic constructs and validation rules.
 */
export declare function getFunctionConfigurationOutput(args: GetFunctionConfigurationOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetFunctionConfigurationResult>;
export interface GetFunctionConfigurationOutputArgs {
    /**
     * The ARN for the function generated by the service
     */
    functionArn: pulumi.Input<string>;
}
