import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::Backup::BackupPlan
 */
export declare class BackupPlan extends pulumi.CustomResource {
    /**
     * Get an existing BackupPlan resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): BackupPlan;
    /**
     * Returns true if the given object is an instance of BackupPlan.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is BackupPlan;
    /**
     * Uniquely identifies the backup plan to be associated with the selection of resources.
     */
    readonly backupPlan: pulumi.Output<outputs.backup.BackupPlanResourceType>;
    /**
     * An Amazon Resource Name (ARN) that uniquely identifies a backup plan; for example, `arn:aws:backup:us-east-1:123456789012:plan:8F81F553-3A74-4A3F-B93D-B3360DC80C50` .
     */
    readonly backupPlanArn: pulumi.Output<string>;
    /**
     * Uniquely identifies a backup plan.
     */
    readonly backupPlanId: pulumi.Output<string>;
    /**
     * The tags to assign to the backup plan.
     */
    readonly backupPlanTags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Unique, randomly generated, Unicode, UTF-8 encoded strings that are at most 1,024 bytes long. Version Ids cannot be edited.
     */
    readonly versionId: pulumi.Output<string>;
    /**
     * Create a BackupPlan resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: BackupPlanArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a BackupPlan resource.
 */
export interface BackupPlanArgs {
    /**
     * Uniquely identifies the backup plan to be associated with the selection of resources.
     */
    backupPlan: pulumi.Input<inputs.backup.BackupPlanResourceTypeArgs>;
    /**
     * The tags to assign to the backup plan.
     */
    backupPlanTags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
