import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Definition of AWS::Bedrock::Blueprint Resource Type
 */
export declare function getBlueprint(args: GetBlueprintArgs, opts?: pulumi.InvokeOptions): Promise<GetBlueprintResult>;
export interface GetBlueprintArgs {
    /**
     * ARN of a Blueprint
     */
    blueprintArn: string;
}
export interface GetBlueprintResult {
    /**
     * ARN of a Blueprint
     */
    readonly blueprintArn?: string;
    /**
     * Stage of the Blueprint
     */
    readonly blueprintStage?: enums.bedrock.BlueprintStage;
    /**
     * Creation timestamp
     */
    readonly creationTime?: string;
    /**
     * KMS encryption context
     */
    readonly kmsEncryptionContext?: {
        [key: string]: string;
    };
    /**
     * KMS key identifier
     */
    readonly kmsKeyId?: string;
    /**
     * Last modified timestamp
     */
    readonly lastModifiedTime?: string;
    /**
     * Schema of the blueprint
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::Bedrock::Blueprint` for more information about the expected schema for this property.
     */
    readonly schema?: any;
    /**
     * List of Tags
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Definition of AWS::Bedrock::Blueprint Resource Type
 */
export declare function getBlueprintOutput(args: GetBlueprintOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetBlueprintResult>;
export interface GetBlueprintOutputArgs {
    /**
     * ARN of a Blueprint
     */
    blueprintArn: pulumi.Input<string>;
}
