import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::CE::CostCategory. Cost Category enables you to map your cost and usage into meaningful categories. You can use Cost Category to organize your costs using a rule-based engine.
 */
export declare class CostCategory extends pulumi.CustomResource {
    /**
     * Get an existing CostCategory resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): CostCategory;
    /**
     * Returns true if the given object is an instance of CostCategory.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is CostCategory;
    /**
     * Cost category ARN
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The default value for the cost category
     */
    readonly defaultValue: pulumi.Output<string | undefined>;
    /**
     * The Cost Category's effective start date.
     */
    readonly effectiveStart: pulumi.Output<string>;
    /**
     * The unique name of the Cost Category.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The rule schema version in this particular Cost Category.
     */
    readonly ruleVersion: pulumi.Output<enums.ce.CostCategoryRuleVersion>;
    /**
     * JSON array format of Expression in Billing and Cost Management API
     */
    readonly rules: pulumi.Output<string>;
    /**
     * Json array format of CostCategorySplitChargeRule in Billing and Cost Management API
     */
    readonly splitChargeRules: pulumi.Output<string | undefined>;
    /**
     * Tags to assign to the cost category.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a CostCategory resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: CostCategoryArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a CostCategory resource.
 */
export interface CostCategoryArgs {
    /**
     * The default value for the cost category
     */
    defaultValue?: pulumi.Input<string>;
    /**
     * The unique name of the Cost Category.
     */
    name?: pulumi.Input<string>;
    /**
     * The rule schema version in this particular Cost Category.
     */
    ruleVersion: pulumi.Input<enums.ce.CostCategoryRuleVersion>;
    /**
     * JSON array format of Expression in Billing and Cost Management API
     */
    rules: pulumi.Input<string>;
    /**
     * Json array format of CostCategorySplitChargeRule in Billing and Cost Management API
     */
    splitChargeRules?: pulumi.Input<string>;
    /**
     * Tags to assign to the cost category.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
