import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * The AWS::CloudWatch::CompositeAlarm type specifies an alarm which aggregates the states of other Alarms (Metric or Composite Alarms) as defined by the AlarmRule expression
 */
export declare class CompositeAlarm extends pulumi.CustomResource {
    /**
     * Get an existing CompositeAlarm resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): CompositeAlarm;
    /**
     * Returns true if the given object is an instance of CompositeAlarm.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is CompositeAlarm;
    /**
     * Indicates whether actions should be executed during any changes to the alarm state. The default is TRUE.
     */
    readonly actionsEnabled: pulumi.Output<boolean | undefined>;
    /**
     * Actions will be suppressed if the suppressor alarm is in the ALARM state. ActionsSuppressor can be an AlarmName or an Amazon Resource Name (ARN) from an existing alarm.
     */
    readonly actionsSuppressor: pulumi.Output<string | undefined>;
    /**
     * Actions will be suppressed if WaitPeriod is active. The length of time that actions are suppressed is in seconds.
     */
    readonly actionsSuppressorExtensionPeriod: pulumi.Output<number | undefined>;
    /**
     * Actions will be suppressed if ExtensionPeriod is active. The length of time that actions are suppressed is in seconds.
     */
    readonly actionsSuppressorWaitPeriod: pulumi.Output<number | undefined>;
    /**
     * The list of actions to execute when this alarm transitions into an ALARM state from any other state. Specify each action as an Amazon Resource Name (ARN).
     */
    readonly alarmActions: pulumi.Output<string[] | undefined>;
    /**
     * The description of the alarm
     */
    readonly alarmDescription: pulumi.Output<string | undefined>;
    /**
     * The name of the Composite Alarm
     */
    readonly alarmName: pulumi.Output<string | undefined>;
    /**
     * Expression which aggregates the state of other Alarms (Metric or Composite Alarms)
     */
    readonly alarmRule: pulumi.Output<string>;
    /**
     * Amazon Resource Name (ARN) of the alarm
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The actions to execute when this alarm transitions to the INSUFFICIENT_DATA state from any other state. Each action is specified as an Amazon Resource Name (ARN).
     */
    readonly insufficientDataActions: pulumi.Output<string[] | undefined>;
    /**
     * The actions to execute when this alarm transitions to the OK state from any other state. Each action is specified as an Amazon Resource Name (ARN).
     */
    readonly okActions: pulumi.Output<string[] | undefined>;
    /**
     * A list of key-value pairs to associate with the composite alarm. You can associate as many as 50 tags with an alarm.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a CompositeAlarm resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: CompositeAlarmArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a CompositeAlarm resource.
 */
export interface CompositeAlarmArgs {
    /**
     * Indicates whether actions should be executed during any changes to the alarm state. The default is TRUE.
     */
    actionsEnabled?: pulumi.Input<boolean>;
    /**
     * Actions will be suppressed if the suppressor alarm is in the ALARM state. ActionsSuppressor can be an AlarmName or an Amazon Resource Name (ARN) from an existing alarm.
     */
    actionsSuppressor?: pulumi.Input<string>;
    /**
     * Actions will be suppressed if WaitPeriod is active. The length of time that actions are suppressed is in seconds.
     */
    actionsSuppressorExtensionPeriod?: pulumi.Input<number>;
    /**
     * Actions will be suppressed if ExtensionPeriod is active. The length of time that actions are suppressed is in seconds.
     */
    actionsSuppressorWaitPeriod?: pulumi.Input<number>;
    /**
     * The list of actions to execute when this alarm transitions into an ALARM state from any other state. Specify each action as an Amazon Resource Name (ARN).
     */
    alarmActions?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The description of the alarm
     */
    alarmDescription?: pulumi.Input<string>;
    /**
     * The name of the Composite Alarm
     */
    alarmName?: pulumi.Input<string>;
    /**
     * Expression which aggregates the state of other Alarms (Metric or Composite Alarms)
     */
    alarmRule: pulumi.Input<string>;
    /**
     * The actions to execute when this alarm transitions to the INSUFFICIENT_DATA state from any other state. Each action is specified as an Amazon Resource Name (ARN).
     */
    insufficientDataActions?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The actions to execute when this alarm transitions to the OK state from any other state. Each action is specified as an Amazon Resource Name (ARN).
     */
    okActions?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * A list of key-value pairs to associate with the composite alarm. You can associate as many as 50 tags with an alarm.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
