import * as pulumi from "@pulumi/pulumi";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::Connect::IntegrationAssociation
 *
 * ## Example Usage
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const integrationAssociation = new aws_native.connect.IntegrationAssociation("integrationAssociation", {
 *     instanceId: "arn:aws:connect:region-name:aws-account-id:instance/instance-id",
 *     integrationType: aws_native.connect.IntegrationAssociationIntegrationType.LexBot,
 *     integrationArn: "arn:aws:lex:region-name:aws-account-id:bot/bot-name",
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const integrationAssociation = new aws_native.connect.IntegrationAssociation("integrationAssociation", {
 *     instanceId: "arn:aws:connect:region-name:aws-account-id:instance/instance-id",
 *     integrationType: aws_native.connect.IntegrationAssociationIntegrationType.LexBot,
 *     integrationArn: "arn:aws:lex:region-name:aws-account-id:bot-alias/bot-id/alias-id",
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const integrationAssociation = new aws_native.connect.IntegrationAssociation("integrationAssociation", {
 *     instanceId: "arn:aws:connect:region-name:aws-account-id:instance/instance-id",
 *     integrationType: aws_native.connect.IntegrationAssociationIntegrationType.LambdaFunction,
 *     integrationArn: "arn:aws:lambda:region-name:aws-account-id:function:function-arn",
 * });
 *
 * ```
 */
export declare class IntegrationAssociation extends pulumi.CustomResource {
    /**
     * Get an existing IntegrationAssociation resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): IntegrationAssociation;
    /**
     * Returns true if the given object is an instance of IntegrationAssociation.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is IntegrationAssociation;
    /**
     * The Amazon Resource Name (ARN) of the instance.
     *
     * *Minimum* : `1`
     *
     * *Maximum* : `100`
     */
    readonly instanceId: pulumi.Output<string>;
    /**
     * ARN of the integration being associated with the instance.
     *
     * *Minimum* : `1`
     *
     * *Maximum* : `140`
     */
    readonly integrationArn: pulumi.Output<string>;
    /**
     * Identifier of the association with an Amazon Connect instance.
     */
    readonly integrationAssociationId: pulumi.Output<string>;
    /**
     * Specifies the integration type to be associated with the instance.
     *
     * *Allowed Values* : `LEX_BOT` | `LAMBDA_FUNCTION`
     */
    readonly integrationType: pulumi.Output<enums.connect.IntegrationAssociationIntegrationType>;
    /**
     * Create a IntegrationAssociation resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: IntegrationAssociationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a IntegrationAssociation resource.
 */
export interface IntegrationAssociationArgs {
    /**
     * The Amazon Resource Name (ARN) of the instance.
     *
     * *Minimum* : `1`
     *
     * *Maximum* : `100`
     */
    instanceId: pulumi.Input<string>;
    /**
     * ARN of the integration being associated with the instance.
     *
     * *Minimum* : `1`
     *
     * *Maximum* : `140`
     */
    integrationArn: pulumi.Input<string>;
    /**
     * Specifies the integration type to be associated with the instance.
     *
     * *Allowed Values* : `LEX_BOT` | `LAMBDA_FUNCTION`
     */
    integrationType: pulumi.Input<enums.connect.IntegrationAssociationIntegrationType>;
}
