import * as pulumi from "@pulumi/pulumi";
/**
 * Resource Type definition for AWS::Connect::SecurityKey
 *
 * ## Example Usage
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const securityKey = new aws_native.connect.SecurityKey("securityKey", {
 *     instanceId: "arn:aws:connect:region-name:aws-account-id:instance/instance-arn",
 *     key: "valid-pem-key",
 * });
 *
 * ```
 */
export declare class SecurityKey extends pulumi.CustomResource {
    /**
     * Get an existing SecurityKey resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): SecurityKey;
    /**
     * Returns true if the given object is an instance of SecurityKey.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is SecurityKey;
    /**
     * An `AssociationId` is automatically generated when a storage config is associated with an instance.
     */
    readonly associationId: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of the instance.
     *
     * *Minimum* : `1`
     *
     * *Maximum* : `100`
     */
    readonly instanceId: pulumi.Output<string>;
    /**
     * A valid security key in PEM format. For example:
     *
     * `"-----BEGIN PUBLIC KEY-----\ [a lot of characters] ----END PUBLIC KEY-----"`
     *
     * *Minimum* : `1`
     *
     * *Maximum* : `1024`
     */
    readonly key: pulumi.Output<string>;
    /**
     * Create a SecurityKey resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: SecurityKeyArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a SecurityKey resource.
 */
export interface SecurityKeyArgs {
    /**
     * The Amazon Resource Name (ARN) of the instance.
     *
     * *Minimum* : `1`
     *
     * *Maximum* : `100`
     */
    instanceId: pulumi.Input<string>;
    /**
     * A valid security key in PEM format. For example:
     *
     * `"-----BEGIN PUBLIC KEY-----\ [a lot of characters] ----END PUBLIC KEY-----"`
     *
     * *Minimum* : `1`
     *
     * *Maximum* : `1024`
     */
    key: pulumi.Input<string>;
}
