import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::Connect::SecurityProfile
 */
export declare class SecurityProfile extends pulumi.CustomResource {
    /**
     * Get an existing SecurityProfile resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): SecurityProfile;
    /**
     * Returns true if the given object is an instance of SecurityProfile.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is SecurityProfile;
    /**
     * The identifier of the hierarchy group that a security profile uses to restrict access to resources in Amazon Connect.
     */
    readonly allowedAccessControlHierarchyGroupId: pulumi.Output<string | undefined>;
    /**
     * The list of tags that a security profile uses to restrict access to resources in Amazon Connect.
     */
    readonly allowedAccessControlTags: pulumi.Output<outputs.connect.SecurityProfileTag[] | undefined>;
    /**
     * A list of third-party applications that the security profile will give access to.
     */
    readonly applications: pulumi.Output<outputs.connect.SecurityProfileApplication[] | undefined>;
    /**
     * The description of the security profile.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The list of resources that a security profile applies hierarchy restrictions to in Amazon Connect.
     */
    readonly hierarchyRestrictedResources: pulumi.Output<string[] | undefined>;
    /**
     * The identifier of the Amazon Connect instance.
     */
    readonly instanceArn: pulumi.Output<string>;
    /**
     * The AWS Region where this resource was last modified.
     */
    readonly lastModifiedRegion: pulumi.Output<string>;
    /**
     * The timestamp when this resource was last modified.
     */
    readonly lastModifiedTime: pulumi.Output<number>;
    /**
     * Permissions assigned to the security profile.
     */
    readonly permissions: pulumi.Output<string[] | undefined>;
    /**
     * The Amazon Resource Name (ARN) for the security profile.
     */
    readonly securityProfileArn: pulumi.Output<string>;
    /**
     * The name of the security profile.
     */
    readonly securityProfileName: pulumi.Output<string>;
    /**
     * The list of resources that a security profile applies tag restrictions to in Amazon Connect.
     */
    readonly tagRestrictedResources: pulumi.Output<string[] | undefined>;
    /**
     * The tags used to organize, track, or control access for this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a SecurityProfile resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: SecurityProfileArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a SecurityProfile resource.
 */
export interface SecurityProfileArgs {
    /**
     * The identifier of the hierarchy group that a security profile uses to restrict access to resources in Amazon Connect.
     */
    allowedAccessControlHierarchyGroupId?: pulumi.Input<string>;
    /**
     * The list of tags that a security profile uses to restrict access to resources in Amazon Connect.
     */
    allowedAccessControlTags?: pulumi.Input<pulumi.Input<inputs.connect.SecurityProfileTagArgs>[]>;
    /**
     * A list of third-party applications that the security profile will give access to.
     */
    applications?: pulumi.Input<pulumi.Input<inputs.connect.SecurityProfileApplicationArgs>[]>;
    /**
     * The description of the security profile.
     */
    description?: pulumi.Input<string>;
    /**
     * The list of resources that a security profile applies hierarchy restrictions to in Amazon Connect.
     */
    hierarchyRestrictedResources?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The identifier of the Amazon Connect instance.
     */
    instanceArn: pulumi.Input<string>;
    /**
     * Permissions assigned to the security profile.
     */
    permissions?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The name of the security profile.
     */
    securityProfileName?: pulumi.Input<string>;
    /**
     * The list of resources that a security profile applies tag restrictions to in Amazon Connect.
     */
    tagRestrictedResources?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The tags used to organize, track, or control access for this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
