import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource schema for AWS::DataSync::LocationNFS
 */
export declare function getLocationNfs(args: GetLocationNfsArgs, opts?: pulumi.InvokeOptions): Promise<GetLocationNfsResult>;
export interface GetLocationNfsArgs {
    /**
     * The Amazon Resource Name (ARN) of the NFS location.
     */
    locationArn: string;
}
export interface GetLocationNfsResult {
    /**
     * The Amazon Resource Name (ARN) of the NFS location.
     */
    readonly locationArn?: string;
    /**
     * The URL of the NFS location that was described.
     */
    readonly locationUri?: string;
    /**
     * Specifies the options that DataSync can use to mount your NFS file server.
     */
    readonly mountOptions?: outputs.datasync.LocationNfsMountOptions;
    /**
     * Specifies the Amazon Resource Name (ARN) of the DataSync agent that can connect to your NFS file server.
     *
     * You can specify more than one agent. For more information, see [Using multiple DataSync agents](https://docs.aws.amazon.com/datasync/latest/userguide/do-i-need-datasync-agent.html#multiple-agents) .
     */
    readonly onPremConfig?: outputs.datasync.LocationNfsOnPremConfig;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Resource schema for AWS::DataSync::LocationNFS
 */
export declare function getLocationNfsOutput(args: GetLocationNfsOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetLocationNfsResult>;
export interface GetLocationNfsOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the NFS location.
     */
    locationArn: pulumi.Input<string>;
}
