import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource schema for AWS::DataSync::LocationAzureBlob.
 */
export declare class LocationAzureBlob extends pulumi.CustomResource {
    /**
     * Get an existing LocationAzureBlob resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): LocationAzureBlob;
    /**
     * Returns true if the given object is an instance of LocationAzureBlob.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is LocationAzureBlob;
    /**
     * The Amazon Resource Names (ARNs) of agents to use for an Azure Blob Location.
     */
    readonly agentArns: pulumi.Output<string[]>;
    /**
     * Specifies an access tier for the objects you're transferring into your Azure Blob Storage container.
     */
    readonly azureAccessTier: pulumi.Output<enums.datasync.LocationAzureBlobAzureAccessTier | undefined>;
    /**
     * The specific authentication type that you want DataSync to use to access your Azure Blob Container.
     */
    readonly azureBlobAuthenticationType: pulumi.Output<enums.datasync.LocationAzureBlobAzureBlobAuthenticationType>;
    /**
     * The URL of the Azure Blob container that was described.
     */
    readonly azureBlobContainerUrl: pulumi.Output<string | undefined>;
    /**
     * Specifies the SAS configuration that allows DataSync to access your Azure Blob Storage.
     */
    readonly azureBlobSasConfiguration: pulumi.Output<outputs.datasync.LocationAzureBlobAzureBlobSasConfiguration | undefined>;
    /**
     * Specifies a blob type for the objects you're transferring into your Azure Blob Storage container.
     */
    readonly azureBlobType: pulumi.Output<enums.datasync.LocationAzureBlobAzureBlobType | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the Azure Blob Location that is created.
     */
    readonly locationArn: pulumi.Output<string>;
    /**
     * The URL of the Azure Blob Location that was described.
     */
    readonly locationUri: pulumi.Output<string>;
    /**
     * The subdirectory in the Azure Blob Container that is used to read data from the Azure Blob Source Location.
     */
    readonly subdirectory: pulumi.Output<string | undefined>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a LocationAzureBlob resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: LocationAzureBlobArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a LocationAzureBlob resource.
 */
export interface LocationAzureBlobArgs {
    /**
     * The Amazon Resource Names (ARNs) of agents to use for an Azure Blob Location.
     */
    agentArns: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Specifies an access tier for the objects you're transferring into your Azure Blob Storage container.
     */
    azureAccessTier?: pulumi.Input<enums.datasync.LocationAzureBlobAzureAccessTier>;
    /**
     * The specific authentication type that you want DataSync to use to access your Azure Blob Container.
     */
    azureBlobAuthenticationType: pulumi.Input<enums.datasync.LocationAzureBlobAzureBlobAuthenticationType>;
    /**
     * The URL of the Azure Blob container that was described.
     */
    azureBlobContainerUrl?: pulumi.Input<string>;
    /**
     * Specifies the SAS configuration that allows DataSync to access your Azure Blob Storage.
     */
    azureBlobSasConfiguration?: pulumi.Input<inputs.datasync.LocationAzureBlobAzureBlobSasConfigurationArgs>;
    /**
     * Specifies a blob type for the objects you're transferring into your Azure Blob Storage container.
     */
    azureBlobType?: pulumi.Input<enums.datasync.LocationAzureBlobAzureBlobType>;
    /**
     * The subdirectory in the Azure Blob Container that is used to read data from the Azure Blob Source Location.
     */
    subdirectory?: pulumi.Input<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
