import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource schema for AWS::DataSync::LocationFSxWindows.
 */
export declare class LocationFSxWindows extends pulumi.CustomResource {
    /**
     * Get an existing LocationFSxWindows resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): LocationFSxWindows;
    /**
     * Returns true if the given object is an instance of LocationFSxWindows.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is LocationFSxWindows;
    /**
     * The name of the Windows domain that the FSx for Windows server belongs to.
     */
    readonly domain: pulumi.Output<string | undefined>;
    /**
     * The Amazon Resource Name (ARN) for the FSx for Windows file system.
     */
    readonly fsxFilesystemArn: pulumi.Output<string | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the Amazon FSx for Windows file system location that is created.
     */
    readonly locationArn: pulumi.Output<string>;
    /**
     * The URL of the FSx for Windows location that was described.
     */
    readonly locationUri: pulumi.Output<string>;
    /**
     * The password of the user who has the permissions to access files and folders in the FSx for Windows file system.
     */
    readonly password: pulumi.Output<string | undefined>;
    /**
     * The ARNs of the security groups that are to use to configure the FSx for Windows file system.
     */
    readonly securityGroupArns: pulumi.Output<string[]>;
    /**
     * A subdirectory in the location's path.
     */
    readonly subdirectory: pulumi.Output<string | undefined>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The user who has the permissions to access files and folders in the FSx for Windows file system.
     */
    readonly user: pulumi.Output<string>;
    /**
     * Create a LocationFSxWindows resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: LocationFSxWindowsArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a LocationFSxWindows resource.
 */
export interface LocationFSxWindowsArgs {
    /**
     * The name of the Windows domain that the FSx for Windows server belongs to.
     */
    domain?: pulumi.Input<string>;
    /**
     * The Amazon Resource Name (ARN) for the FSx for Windows file system.
     */
    fsxFilesystemArn?: pulumi.Input<string>;
    /**
     * The password of the user who has the permissions to access files and folders in the FSx for Windows file system.
     */
    password?: pulumi.Input<string>;
    /**
     * The ARNs of the security groups that are to use to configure the FSx for Windows file system.
     */
    securityGroupArns: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * A subdirectory in the location's path.
     */
    subdirectory?: pulumi.Input<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The user who has the permissions to access files and folders in the FSx for Windows file system.
     */
    user: pulumi.Input<string>;
}
