import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::EC2::DHCPOptions
 */
export declare class DhcpOptions extends pulumi.CustomResource {
    /**
     * Get an existing DhcpOptions resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): DhcpOptions;
    /**
     * Returns true if the given object is an instance of DhcpOptions.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is DhcpOptions;
    /**
     * The ID of the DHCP options set.
     */
    readonly dhcpOptionsId: pulumi.Output<string>;
    /**
     * This value is used to complete unqualified DNS hostnames.
     */
    readonly domainName: pulumi.Output<string | undefined>;
    /**
     * The IPv4 addresses of up to four domain name servers, or AmazonProvidedDNS.
     */
    readonly domainNameServers: pulumi.Output<string[] | undefined>;
    /**
     * The preferred Lease Time for ipV6 address in seconds.
     */
    readonly ipv6AddressPreferredLeaseTime: pulumi.Output<number | undefined>;
    /**
     * The IPv4 addresses of up to four NetBIOS name servers.
     */
    readonly netbiosNameServers: pulumi.Output<string[] | undefined>;
    /**
     * The NetBIOS node type (1, 2, 4, or 8).
     */
    readonly netbiosNodeType: pulumi.Output<number | undefined>;
    /**
     * The IPv4 addresses of up to four Network Time Protocol (NTP) servers.
     */
    readonly ntpServers: pulumi.Output<string[] | undefined>;
    /**
     * Any tags assigned to the DHCP options set.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a DhcpOptions resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: DhcpOptionsArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a DhcpOptions resource.
 */
export interface DhcpOptionsArgs {
    /**
     * This value is used to complete unqualified DNS hostnames.
     */
    domainName?: pulumi.Input<string>;
    /**
     * The IPv4 addresses of up to four domain name servers, or AmazonProvidedDNS.
     */
    domainNameServers?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The preferred Lease Time for ipV6 address in seconds.
     */
    ipv6AddressPreferredLeaseTime?: pulumi.Input<number>;
    /**
     * The IPv4 addresses of up to four NetBIOS name servers.
     */
    netbiosNameServers?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The NetBIOS node type (1, 2, 4, or 8).
     */
    netbiosNodeType?: pulumi.Input<number>;
    /**
     * The IPv4 addresses of up to four Network Time Protocol (NTP) servers.
     */
    ntpServers?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Any tags assigned to the DHCP options set.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
