import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Specifies a route table for the specified VPC. After you create a route table, you can add routes and associate the table with a subnet.
 *  For more information, see [Route tables](https://docs.aws.amazon.com/vpc/latest/userguide/VPC_Route_Tables.html) in the *Amazon VPC User Guide*.
 */
export declare function getRouteTable(args: GetRouteTableArgs, opts?: pulumi.InvokeOptions): Promise<GetRouteTableResult>;
export interface GetRouteTableArgs {
    /**
     * The ID of the route table.
     */
    routeTableId: string;
}
export interface GetRouteTableResult {
    /**
     * The ID of the route table.
     */
    readonly routeTableId?: string;
    /**
     * Any tags assigned to the route table.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Specifies a route table for the specified VPC. After you create a route table, you can add routes and associate the table with a subnet.
 *  For more information, see [Route tables](https://docs.aws.amazon.com/vpc/latest/userguide/VPC_Route_Tables.html) in the *Amazon VPC User Guide*.
 */
export declare function getRouteTableOutput(args: GetRouteTableOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetRouteTableResult>;
export interface GetRouteTableOutputArgs {
    /**
     * The ID of the route table.
     */
    routeTableId: pulumi.Input<string>;
}
