import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource schema for AWS::EC2::NetworkInsightsPath
 */
export declare class NetworkInsightsPath extends pulumi.CustomResource {
    /**
     * Get an existing NetworkInsightsPath resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): NetworkInsightsPath;
    /**
     * Returns true if the given object is an instance of NetworkInsightsPath.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is NetworkInsightsPath;
    /**
     * The time stamp when the path was created.
     */
    readonly createdDate: pulumi.Output<string>;
    /**
     * The ID or ARN of the destination. If the resource is in another account, you must specify an ARN.
     */
    readonly destination: pulumi.Output<string | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the destination.
     */
    readonly destinationArn: pulumi.Output<string>;
    /**
     * The IP address of the destination.
     */
    readonly destinationIp: pulumi.Output<string | undefined>;
    /**
     * The destination port.
     */
    readonly destinationPort: pulumi.Output<number | undefined>;
    /**
     * Scopes the analysis to network paths that match specific filters at the destination. If you specify this parameter, you can't specify the parameter for the destination IP address.
     */
    readonly filterAtDestination: pulumi.Output<outputs.ec2.NetworkInsightsPathPathFilter | undefined>;
    /**
     * Scopes the analysis to network paths that match specific filters at the source. If you specify this parameter, you can't specify the parameters for the source IP address or the destination port.
     */
    readonly filterAtSource: pulumi.Output<outputs.ec2.NetworkInsightsPathPathFilter | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the path.
     */
    readonly networkInsightsPathArn: pulumi.Output<string>;
    /**
     * The ID of the path.
     */
    readonly networkInsightsPathId: pulumi.Output<string>;
    /**
     * The protocol.
     */
    readonly protocol: pulumi.Output<enums.ec2.NetworkInsightsPathProtocol>;
    /**
     * The ID or ARN of the source. If the resource is in another account, you must specify an ARN.
     */
    readonly source: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of the source.
     */
    readonly sourceArn: pulumi.Output<string>;
    /**
     * The IP address of the source.
     */
    readonly sourceIp: pulumi.Output<string | undefined>;
    /**
     * The tags to add to the path.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a NetworkInsightsPath resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: NetworkInsightsPathArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a NetworkInsightsPath resource.
 */
export interface NetworkInsightsPathArgs {
    /**
     * The ID or ARN of the destination. If the resource is in another account, you must specify an ARN.
     */
    destination?: pulumi.Input<string>;
    /**
     * The IP address of the destination.
     */
    destinationIp?: pulumi.Input<string>;
    /**
     * The destination port.
     */
    destinationPort?: pulumi.Input<number>;
    /**
     * Scopes the analysis to network paths that match specific filters at the destination. If you specify this parameter, you can't specify the parameter for the destination IP address.
     */
    filterAtDestination?: pulumi.Input<inputs.ec2.NetworkInsightsPathPathFilterArgs>;
    /**
     * Scopes the analysis to network paths that match specific filters at the source. If you specify this parameter, you can't specify the parameters for the source IP address or the destination port.
     */
    filterAtSource?: pulumi.Input<inputs.ec2.NetworkInsightsPathPathFilterArgs>;
    /**
     * The protocol.
     */
    protocol: pulumi.Input<enums.ec2.NetworkInsightsPathProtocol>;
    /**
     * The ID or ARN of the source. If the resource is in another account, you must specify an ARN.
     */
    source: pulumi.Input<string>;
    /**
     * The IP address of the source.
     */
    sourceIp?: pulumi.Input<string>;
    /**
     * The tags to add to the path.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
