import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::EC2::TransitGatewayVpcAttachment
 */
export declare class TransitGatewayVpcAttachment extends pulumi.CustomResource {
    /**
     * Get an existing TransitGatewayVpcAttachment resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): TransitGatewayVpcAttachment;
    /**
     * Returns true if the given object is an instance of TransitGatewayVpcAttachment.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is TransitGatewayVpcAttachment;
    /**
     * The IDs of one or more subnets to add. You can specify at most one subnet per Availability Zone.
     */
    readonly addSubnetIds: pulumi.Output<string[] | undefined>;
    /**
     * The ID of the attachment.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * The options for the transit gateway vpc attachment.
     */
    readonly options: pulumi.Output<outputs.ec2.OptionsProperties | undefined>;
    /**
     * The IDs of one or more subnets to remove.
     */
    readonly removeSubnetIds: pulumi.Output<string[] | undefined>;
    /**
     * The IDs of the subnets.
     */
    readonly subnetIds: pulumi.Output<string[]>;
    /**
     * The tags for the VPC attachment.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The ID of the transit gateway.
     */
    readonly transitGatewayId: pulumi.Output<string>;
    /**
     * The ID of the VPC.
     */
    readonly vpcId: pulumi.Output<string>;
    /**
     * Create a TransitGatewayVpcAttachment resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: TransitGatewayVpcAttachmentArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a TransitGatewayVpcAttachment resource.
 */
export interface TransitGatewayVpcAttachmentArgs {
    /**
     * The IDs of one or more subnets to add. You can specify at most one subnet per Availability Zone.
     */
    addSubnetIds?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The options for the transit gateway vpc attachment.
     */
    options?: pulumi.Input<inputs.ec2.OptionsPropertiesArgs>;
    /**
     * The IDs of one or more subnets to remove.
     */
    removeSubnetIds?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The IDs of the subnets.
     */
    subnetIds: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The tags for the VPC attachment.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The ID of the transit gateway.
     */
    transitGatewayId: pulumi.Input<string>;
    /**
     * The ID of the VPC.
     */
    vpcId: pulumi.Input<string>;
}
