import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::ElasticBeanstalk::ConfigurationTemplate
 */
export declare function getConfigurationTemplate(args: GetConfigurationTemplateArgs, opts?: pulumi.InvokeOptions): Promise<GetConfigurationTemplateResult>;
export interface GetConfigurationTemplateArgs {
    /**
     * The name of the Elastic Beanstalk application to associate with this configuration template.
     */
    applicationName: string;
    /**
     * The name of the configuration template
     */
    templateName: string;
}
export interface GetConfigurationTemplateResult {
    /**
     * An optional description for this configuration.
     */
    readonly description?: string;
    /**
     * Option values for the Elastic Beanstalk configuration, such as the instance type. If specified, these values override the values obtained from the solution stack or the source configuration template. For a complete list of Elastic Beanstalk configuration options, see [Option Values](https://docs.aws.amazon.com/elasticbeanstalk/latest/dg/command-options.html) in the AWS Elastic Beanstalk Developer Guide.
     */
    readonly optionSettings?: outputs.elasticbeanstalk.ConfigurationTemplateConfigurationOptionSetting[];
    /**
     * The name of the configuration template
     */
    readonly templateName?: string;
}
/**
 * Resource Type definition for AWS::ElasticBeanstalk::ConfigurationTemplate
 */
export declare function getConfigurationTemplateOutput(args: GetConfigurationTemplateOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetConfigurationTemplateResult>;
export interface GetConfigurationTemplateOutputArgs {
    /**
     * The name of the Elastic Beanstalk application to associate with this configuration template.
     */
    applicationName: pulumi.Input<string>;
    /**
     * The name of the configuration template
     */
    templateName: pulumi.Input<string>;
}
