import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Specifies a listener rule. The listener must be associated with an Application Load Balancer. Each rule consists of a priority, one or more actions, and one or more conditions.
 *  For more information, see [Quotas for your Application Load Balancers](https://docs.aws.amazon.com/elasticloadbalancing/latest/application/load-balancer-limits.html) in the *User Guide for Application Load Balancers*.
 */
export declare function getListenerRule(args: GetListenerRuleArgs, opts?: pulumi.InvokeOptions): Promise<GetListenerRuleResult>;
export interface GetListenerRuleArgs {
    /**
     * The Amazon Resource Name (ARN) of the rule.
     */
    ruleArn: string;
}
export interface GetListenerRuleResult {
    /**
     * The actions.
     *  The rule must include exactly one of the following types of actions: ``forward``, ``fixed-response``, or ``redirect``, and it must be the last action to be performed. If the rule is for an HTTPS listener, it can also optionally include an authentication action.
     */
    readonly actions?: outputs.elasticloadbalancingv2.ListenerRuleAction[];
    /**
     * The conditions.
     *  The rule can optionally include up to one of each of the following conditions: ``http-request-method``, ``host-header``, ``path-pattern``, and ``source-ip``. A rule can also optionally include one or more of each of the following conditions: ``http-header`` and ``query-string``.
     */
    readonly conditions?: outputs.elasticloadbalancingv2.ListenerRuleRuleCondition[];
    /**
     * Indicates whether this is the default rule.
     */
    readonly isDefault?: boolean;
    /**
     * The rule priority. A listener can't have multiple rules with the same priority.
     *  If you try to reorder rules by updating their priorities, do not specify a new priority if an existing rule already uses this priority, as this can cause an error. If you need to reuse a priority with a different rule, you must remove it as a priority first, and then specify it in a subsequent update.
     */
    readonly priority?: number;
    /**
     * The Amazon Resource Name (ARN) of the rule.
     */
    readonly ruleArn?: string;
}
/**
 * Specifies a listener rule. The listener must be associated with an Application Load Balancer. Each rule consists of a priority, one or more actions, and one or more conditions.
 *  For more information, see [Quotas for your Application Load Balancers](https://docs.aws.amazon.com/elasticloadbalancing/latest/application/load-balancer-limits.html) in the *User Guide for Application Load Balancers*.
 */
export declare function getListenerRuleOutput(args: GetListenerRuleOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetListenerRuleResult>;
export interface GetListenerRuleOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the rule.
     */
    ruleArn: pulumi.Input<string>;
}
