import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::ElasticLoadBalancingV2::TrustStoreRevocation
 */
export declare class TrustStoreRevocation extends pulumi.CustomResource {
    /**
     * Get an existing TrustStoreRevocation resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): TrustStoreRevocation;
    /**
     * Returns true if the given object is an instance of TrustStoreRevocation.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is TrustStoreRevocation;
    /**
     * The attributes required to create a trust store revocation.
     */
    readonly revocationContents: pulumi.Output<outputs.elasticloadbalancingv2.TrustStoreRevocationRevocationContent[] | undefined>;
    /**
     * The ID associated with the revocation.
     */
    readonly revocationId: pulumi.Output<number>;
    /**
     * The Amazon Resource Name (ARN) of the trust store.
     */
    readonly trustStoreArn: pulumi.Output<string | undefined>;
    /**
     * The data associated with a trust store revocation
     */
    readonly trustStoreRevocations: pulumi.Output<outputs.elasticloadbalancingv2.TrustStoreRevocation[]>;
    /**
     * Create a TrustStoreRevocation resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: TrustStoreRevocationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a TrustStoreRevocation resource.
 */
export interface TrustStoreRevocationArgs {
    /**
     * The attributes required to create a trust store revocation.
     */
    revocationContents?: pulumi.Input<pulumi.Input<inputs.elasticloadbalancingv2.TrustStoreRevocationRevocationContentArgs>[]>;
    /**
     * The Amazon Resource Name (ARN) of the trust store.
     */
    trustStoreArn?: pulumi.Input<string>;
}
