import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Schema for AWS::EMR::Step
 */
export declare class Step extends pulumi.CustomResource {
    /**
     * Get an existing Step resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Step;
    /**
     * Returns true if the given object is an instance of Step.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Step;
    /**
     * This specifies what action to take when the cluster step fails. Possible values are CANCEL_AND_WAIT and CONTINUE.
     */
    readonly actionOnFailure: pulumi.Output<string>;
    /**
     * ID generated by service
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * The HadoopJarStepConfig property type specifies a job flow step consisting of a JAR file whose main function will be executed. The main function submits a job for the cluster to execute as a step on the master node, and then waits for the job to finish or fail before executing subsequent steps.
     */
    readonly hadoopJarStep: pulumi.Output<outputs.emr.StepHadoopJarStepConfig>;
    /**
     * A string that uniquely identifies the cluster (job flow).
     */
    readonly jobFlowId: pulumi.Output<string>;
    /**
     * The name of the cluster step.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Create a Step resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: StepArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Step resource.
 */
export interface StepArgs {
    /**
     * This specifies what action to take when the cluster step fails. Possible values are CANCEL_AND_WAIT and CONTINUE.
     */
    actionOnFailure: pulumi.Input<string>;
    /**
     * The HadoopJarStepConfig property type specifies a job flow step consisting of a JAR file whose main function will be executed. The main function submits a job for the cluster to execute as a step on the master node, and then waits for the job to finish or fail before executing subsequent steps.
     */
    hadoopJarStep: pulumi.Input<inputs.emr.StepHadoopJarStepConfigArgs>;
    /**
     * A string that uniquely identifies the cluster (job flow).
     */
    jobFlowId: pulumi.Input<string>;
    /**
     * The name of the cluster step.
     */
    name?: pulumi.Input<string>;
}
