import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::Events::Connection.
 */
export declare function getConnection(args: GetConnectionArgs, opts?: pulumi.InvokeOptions): Promise<GetConnectionResult>;
export interface GetConnectionArgs {
    /**
     * Name of the connection.
     */
    name: string;
}
export interface GetConnectionResult {
    /**
     * The arn of the connection resource.
     */
    readonly arn?: string;
    /**
     * The arn of the connection resource to be used in IAM policies.
     */
    readonly arnForPolicy?: string;
    /**
     * The authorization parameters to use to authorize with the endpoint.
     *
     * You must include only authorization parameters for the `AuthorizationType` you specify.
     */
    readonly authParameters?: outputs.events.ConnectionAuthParameters;
    /**
     * The type of authorization to use for the connection.
     *
     * > OAUTH tokens are refreshed when a 401 or 407 response is returned.
     */
    readonly authorizationType?: enums.events.ConnectionAuthorizationType;
    /**
     * Description of the connection.
     */
    readonly description?: string;
    /**
     * The private resource the HTTP request will be sent to.
     */
    readonly invocationConnectivityParameters?: outputs.events.InvocationConnectivityParametersProperties;
    readonly kmsKeyIdentifier?: string;
    /**
     * The arn of the secrets manager secret created in the customer account.
     */
    readonly secretArn?: string;
}
/**
 * Resource Type definition for AWS::Events::Connection.
 */
export declare function getConnectionOutput(args: GetConnectionOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetConnectionResult>;
export interface GetConnectionOutputArgs {
    /**
     * Name of the connection.
     */
    name: pulumi.Input<string>;
}
