import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type Definition for AWS::Forecast::Dataset
 */
export declare class Dataset extends pulumi.CustomResource {
    /**
     * Get an existing Dataset resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Dataset;
    /**
     * Returns true if the given object is an instance of Dataset.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Dataset;
    /**
     * The Amazon Resource Name (ARN) of the dataset.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Frequency of data collection. This parameter is required for RELATED_TIME_SERIES
     */
    readonly dataFrequency: pulumi.Output<string | undefined>;
    /**
     * A name for the dataset
     */
    readonly datasetName: pulumi.Output<string>;
    /**
     * The dataset type
     */
    readonly datasetType: pulumi.Output<enums.forecast.DatasetType>;
    /**
     * The domain associated with the dataset
     */
    readonly domain: pulumi.Output<enums.forecast.DatasetDomain>;
    /**
     * A Key Management Service (KMS) key and the Identity and Access Management (IAM) role that Amazon Forecast can assume to access the key.
     */
    readonly encryptionConfig: pulumi.Output<outputs.forecast.EncryptionConfigProperties | undefined>;
    /**
     * The schema for the dataset. The schema attributes and their order must match the fields in your data. The dataset `Domain` and `DatasetType` that you choose determine the minimum required fields in your training data. For information about the required fields for a specific dataset domain and type, see [Dataset Domains and Dataset Types](https://docs.aws.amazon.com/forecast/latest/dg/howitworks-domains-ds-types.html) .
     */
    readonly schema: pulumi.Output<outputs.forecast.SchemaProperties>;
    /**
     * An array of key-value pairs to apply to this resource.
     *
     * For more information, see [Tag](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resource-tags.html) .
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a Dataset resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: DatasetArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Dataset resource.
 */
export interface DatasetArgs {
    /**
     * Frequency of data collection. This parameter is required for RELATED_TIME_SERIES
     */
    dataFrequency?: pulumi.Input<string>;
    /**
     * A name for the dataset
     */
    datasetName?: pulumi.Input<string>;
    /**
     * The dataset type
     */
    datasetType: pulumi.Input<enums.forecast.DatasetType>;
    /**
     * The domain associated with the dataset
     */
    domain: pulumi.Input<enums.forecast.DatasetDomain>;
    /**
     * A Key Management Service (KMS) key and the Identity and Access Management (IAM) role that Amazon Forecast can assume to access the key.
     */
    encryptionConfig?: pulumi.Input<inputs.forecast.EncryptionConfigPropertiesArgs>;
    /**
     * The schema for the dataset. The schema attributes and their order must match the fields in your data. The dataset `Domain` and `DatasetType` that you choose determine the minimum required fields in your training data. For information about the required fields for a specific dataset domain and type, see [Dataset Domains and Dataset Types](https://docs.aws.amazon.com/forecast/latest/dg/howitworks-domains-ds-types.html) .
     */
    schema: pulumi.Input<inputs.forecast.SchemaPropertiesArgs>;
    /**
     * An array of key-value pairs to apply to this resource.
     *
     * For more information, see [Tag](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resource-tags.html) .
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
