import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * A resource schema for a List in Amazon Fraud Detector.
 */
export declare class List extends pulumi.CustomResource {
    /**
     * Get an existing List resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): List;
    /**
     * Returns true if the given object is an instance of List.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is List;
    /**
     * The list ARN.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The time when the list was created.
     */
    readonly createdTime: pulumi.Output<string>;
    /**
     * The description of the list.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The elements in this list.
     */
    readonly elements: pulumi.Output<string[] | undefined>;
    /**
     * The time when the list was last updated.
     */
    readonly lastUpdatedTime: pulumi.Output<string>;
    /**
     * The name of the list.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Tags associated with this list.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The variable type of the list.
     */
    readonly variableType: pulumi.Output<string | undefined>;
    /**
     * Create a List resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: ListArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a List resource.
 */
export interface ListArgs {
    /**
     * The description of the list.
     */
    description?: pulumi.Input<string>;
    /**
     * The elements in this list.
     */
    elements?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The name of the list.
     */
    name?: pulumi.Input<string>;
    /**
     * Tags associated with this list.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The variable type of the list.
     */
    variableType?: pulumi.Input<string>;
}
