import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::GlobalAccelerator::EndpointGroup
 */
export declare class EndpointGroup extends pulumi.CustomResource {
    /**
     * Get an existing EndpointGroup resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): EndpointGroup;
    /**
     * Returns true if the given object is an instance of EndpointGroup.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is EndpointGroup;
    /**
     * The list of endpoint objects.
     */
    readonly endpointConfigurations: pulumi.Output<outputs.globalaccelerator.EndpointGroupEndpointConfiguration[] | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the endpoint group
     */
    readonly endpointGroupArn: pulumi.Output<string>;
    /**
     * The name of the AWS Region where the endpoint group is located
     */
    readonly endpointGroupRegion: pulumi.Output<string>;
    /**
     * The time in seconds between each health check for an endpoint. Must be a value of 10 or 30
     */
    readonly healthCheckIntervalSeconds: pulumi.Output<number | undefined>;
    /**
     * If the protocol is HTTP/S, then this value provides the ping path that Global Accelerator uses for the destination on the endpoints for health checks. The default is slash (/).
     */
    readonly healthCheckPath: pulumi.Output<string | undefined>;
    /**
     * The port that AWS Global Accelerator uses to check the health of endpoints in this endpoint group.
     */
    readonly healthCheckPort: pulumi.Output<number | undefined>;
    /**
     * The protocol that AWS Global Accelerator uses to check the health of endpoints in this endpoint group.
     */
    readonly healthCheckProtocol: pulumi.Output<enums.globalaccelerator.EndpointGroupHealthCheckProtocol | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the listener
     */
    readonly listenerArn: pulumi.Output<string>;
    /**
     * Allows you to override the destination ports used to route traffic to an endpoint. Using a port override lets you map a list of external destination ports (that your users send traffic to) to a list of internal destination ports that you want an application endpoint to receive traffic on.
     */
    readonly portOverrides: pulumi.Output<outputs.globalaccelerator.EndpointGroupPortOverride[] | undefined>;
    /**
     * The number of consecutive health checks required to set the state of the endpoint to unhealthy.
     */
    readonly thresholdCount: pulumi.Output<number | undefined>;
    /**
     * The percentage of traffic to sent to an AWS Region
     */
    readonly trafficDialPercentage: pulumi.Output<number | undefined>;
    /**
     * Create a EndpointGroup resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: EndpointGroupArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a EndpointGroup resource.
 */
export interface EndpointGroupArgs {
    /**
     * The list of endpoint objects.
     */
    endpointConfigurations?: pulumi.Input<pulumi.Input<inputs.globalaccelerator.EndpointGroupEndpointConfigurationArgs>[]>;
    /**
     * The name of the AWS Region where the endpoint group is located
     */
    endpointGroupRegion: pulumi.Input<string>;
    /**
     * The time in seconds between each health check for an endpoint. Must be a value of 10 or 30
     */
    healthCheckIntervalSeconds?: pulumi.Input<number>;
    /**
     * If the protocol is HTTP/S, then this value provides the ping path that Global Accelerator uses for the destination on the endpoints for health checks. The default is slash (/).
     */
    healthCheckPath?: pulumi.Input<string>;
    /**
     * The port that AWS Global Accelerator uses to check the health of endpoints in this endpoint group.
     */
    healthCheckPort?: pulumi.Input<number>;
    /**
     * The protocol that AWS Global Accelerator uses to check the health of endpoints in this endpoint group.
     */
    healthCheckProtocol?: pulumi.Input<enums.globalaccelerator.EndpointGroupHealthCheckProtocol>;
    /**
     * The Amazon Resource Name (ARN) of the listener
     */
    listenerArn: pulumi.Input<string>;
    /**
     * Allows you to override the destination ports used to route traffic to an endpoint. Using a port override lets you map a list of external destination ports (that your users send traffic to) to a list of internal destination ports that you want an application endpoint to receive traffic on.
     */
    portOverrides?: pulumi.Input<pulumi.Input<inputs.globalaccelerator.EndpointGroupPortOverrideArgs>[]>;
    /**
     * The number of consecutive health checks required to set the state of the endpoint to unhealthy.
     */
    thresholdCount?: pulumi.Input<number>;
    /**
     * The percentage of traffic to sent to an AWS Region
     */
    trafficDialPercentage?: pulumi.Input<number>;
}
