import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::GlobalAccelerator::CrossAccountAttachment
 */
export declare function getCrossAccountAttachment(args: GetCrossAccountAttachmentArgs, opts?: pulumi.InvokeOptions): Promise<GetCrossAccountAttachmentResult>;
export interface GetCrossAccountAttachmentArgs {
    /**
     * The Amazon Resource Name (ARN) of the attachment.
     */
    attachmentArn: string;
}
export interface GetCrossAccountAttachmentResult {
    /**
     * The Amazon Resource Name (ARN) of the attachment.
     */
    readonly attachmentArn?: string;
    /**
     * The Friendly identifier of the attachment.
     */
    readonly name?: string;
    /**
     * Principals to share the resources with.
     */
    readonly principals?: string[];
    /**
     * Resources shared using the attachment.
     */
    readonly resources?: outputs.globalaccelerator.CrossAccountAttachmentResource[];
    /**
     * Add tags for a cross-account attachment.
     *
     * For more information, see [Tagging in AWS Global Accelerator](https://docs.aws.amazon.com/global-accelerator/latest/dg/tagging-in-global-accelerator.html) in the *AWS Global Accelerator Developer Guide* .
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Resource Type definition for AWS::GlobalAccelerator::CrossAccountAttachment
 */
export declare function getCrossAccountAttachmentOutput(args: GetCrossAccountAttachmentOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetCrossAccountAttachmentResult>;
export interface GetCrossAccountAttachmentOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the attachment.
     */
    attachmentArn: pulumi.Input<string>;
}
