import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * AWS Ground Station Mission Profile resource type for CloudFormation.
 */
export declare function getMissionProfile(args: GetMissionProfileArgs, opts?: pulumi.InvokeOptions): Promise<GetMissionProfileResult>;
export interface GetMissionProfileArgs {
    /**
     * The ARN of the mission profile, such as `arn:aws:groundstation:us-east-2:1234567890:mission-profile/9940bf3b-d2ba-427e-9906-842b5e5d2296` .
     */
    arn: string;
    /**
     * The ID of the mission profile, such as `9940bf3b-d2ba-427e-9906-842b5e5d2296` .
     */
    id: string;
}
export interface GetMissionProfileResult {
    /**
     * The ARN of the mission profile, such as `arn:aws:groundstation:us-east-2:1234567890:mission-profile/9940bf3b-d2ba-427e-9906-842b5e5d2296` .
     */
    readonly arn?: string;
    /**
     * Post-pass time needed after the contact.
     */
    readonly contactPostPassDurationSeconds?: number;
    /**
     * Pre-pass time needed before the contact.
     */
    readonly contactPrePassDurationSeconds?: number;
    /**
     * A list containing lists of config ARNs. Each list of config ARNs is an edge, with a "from" config and a "to" config.
     */
    readonly dataflowEdges?: outputs.groundstation.MissionProfileDataflowEdge[];
    /**
     * The ID of the mission profile, such as `9940bf3b-d2ba-427e-9906-842b5e5d2296` .
     */
    readonly id?: string;
    /**
     * Visibilities with shorter duration than the specified minimum viable contact duration will be ignored when searching for available contacts.
     */
    readonly minimumViableContactDurationSeconds?: number;
    /**
     * A name used to identify a mission profile.
     */
    readonly name?: string;
    /**
     * The region of the mission profile.
     */
    readonly region?: string;
    /**
     * The ARN of a KMS Key used for encrypting data during transmission from the source to destination locations.
     */
    readonly streamsKmsKey?: outputs.groundstation.MissionProfileStreamsKmsKey;
    /**
     * The ARN of the KMS Key or Alias Key role used to define permissions on KMS Key usage.
     */
    readonly streamsKmsRole?: string;
    /**
     * Tags assigned to the mission profile.
     */
    readonly tags?: outputs.Tag[];
    /**
     * The ARN of a tracking config objects that defines how to track the satellite through the sky during a contact.
     */
    readonly trackingConfigArn?: string;
}
/**
 * AWS Ground Station Mission Profile resource type for CloudFormation.
 */
export declare function getMissionProfileOutput(args: GetMissionProfileOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetMissionProfileResult>;
export interface GetMissionProfileOutputArgs {
    /**
     * The ARN of the mission profile, such as `arn:aws:groundstation:us-east-2:1234567890:mission-profile/9940bf3b-d2ba-427e-9906-842b5e5d2296` .
     */
    arn: pulumi.Input<string>;
    /**
     * The ID of the mission profile, such as `9940bf3b-d2ba-427e-9906-842b5e5d2296` .
     */
    id: pulumi.Input<string>;
}
