import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource schema for AWS::IoTSiteWise::Dashboard
 */
export declare class Dashboard extends pulumi.CustomResource {
    /**
     * Get an existing Dashboard resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Dashboard;
    /**
     * Returns true if the given object is an instance of Dashboard.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Dashboard;
    /**
     * The ARN of the dashboard.
     */
    readonly dashboardArn: pulumi.Output<string>;
    /**
     * The dashboard definition specified in a JSON literal.
     */
    readonly dashboardDefinition: pulumi.Output<string>;
    /**
     * A description for the dashboard.
     */
    readonly dashboardDescription: pulumi.Output<string>;
    /**
     * The ID of the dashboard.
     */
    readonly dashboardId: pulumi.Output<string>;
    /**
     * A friendly name for the dashboard.
     */
    readonly dashboardName: pulumi.Output<string>;
    /**
     * The ID of the project in which to create the dashboard.
     */
    readonly projectId: pulumi.Output<string | undefined>;
    /**
     * A list of key-value pairs that contain metadata for the dashboard.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a Dashboard resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: DashboardArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Dashboard resource.
 */
export interface DashboardArgs {
    /**
     * The dashboard definition specified in a JSON literal.
     */
    dashboardDefinition: pulumi.Input<string>;
    /**
     * A description for the dashboard.
     */
    dashboardDescription: pulumi.Input<string>;
    /**
     * A friendly name for the dashboard.
     */
    dashboardName?: pulumi.Input<string>;
    /**
     * The ID of the project in which to create the dashboard.
     */
    projectId?: pulumi.Input<string>;
    /**
     * A list of key-value pairs that contain metadata for the dashboard.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
