import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Destination's resource schema demonstrating some basic constructs and validation rules.
 */
export declare class Destination extends pulumi.CustomResource {
    /**
     * Get an existing Destination resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Destination;
    /**
     * Returns true if the given object is an instance of Destination.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Destination;
    /**
     * Destination arn. Returned after successful create.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Destination description
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * Destination expression
     */
    readonly expression: pulumi.Output<string>;
    /**
     * Must be RuleName
     */
    readonly expressionType: pulumi.Output<enums.iotwireless.DestinationExpressionType>;
    /**
     * Unique name of destination
     */
    readonly name: pulumi.Output<string>;
    /**
     * AWS role ARN that grants access
     */
    readonly roleArn: pulumi.Output<string | undefined>;
    /**
     * A list of key-value pairs that contain metadata for the destination.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a Destination resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: DestinationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Destination resource.
 */
export interface DestinationArgs {
    /**
     * Destination description
     */
    description?: pulumi.Input<string>;
    /**
     * Destination expression
     */
    expression: pulumi.Input<string>;
    /**
     * Must be RuleName
     */
    expressionType: pulumi.Input<enums.iotwireless.DestinationExpressionType>;
    /**
     * Unique name of destination
     */
    name?: pulumi.Input<string>;
    /**
     * AWS role ARN that grants access
     */
    roleArn?: pulumi.Input<string>;
    /**
     * A list of key-value pairs that contain metadata for the destination.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
