import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * A version is a numbered snapshot of your work that you can publish for use in different parts of your workflow, such as development, beta deployment, and production.
 */
export declare class BotVersion extends pulumi.CustomResource {
    /**
     * Get an existing BotVersion resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): BotVersion;
    /**
     * Returns true if the given object is an instance of BotVersion.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is BotVersion;
    /**
     * The unique identifier of the bot.
     */
    readonly botId: pulumi.Output<string>;
    /**
     * The version of the bot.
     */
    readonly botVersion: pulumi.Output<string>;
    /**
     * Specifies the locales that Amazon Lex adds to this version. You can choose the Draft version or any other previously published version for each locale. When you specify a source version, the locale data is copied from the source version to the new version.
     */
    readonly botVersionLocaleSpecification: pulumi.Output<outputs.lex.BotVersionLocaleSpecification[]>;
    /**
     * The description of the version.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * Create a BotVersion resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: BotVersionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a BotVersion resource.
 */
export interface BotVersionArgs {
    /**
     * The unique identifier of the bot.
     */
    botId: pulumi.Input<string>;
    /**
     * Specifies the locales that Amazon Lex adds to this version. You can choose the Draft version or any other previously published version for each locale. When you specify a source version, the locale data is copied from the source version to the new version.
     */
    botVersionLocaleSpecification: pulumi.Input<pulumi.Input<inputs.lex.BotVersionLocaleSpecificationArgs>[]>;
    /**
     * The description of the version.
     */
    description?: pulumi.Input<string>;
}
