import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * The AWS::MemoryDB::SubnetGroup resource creates an Amazon MemoryDB Subnet Group.
 */
export declare class SubnetGroup extends pulumi.CustomResource {
    /**
     * Get an existing SubnetGroup resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): SubnetGroup;
    /**
     * Returns true if the given object is an instance of SubnetGroup.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is SubnetGroup;
    /**
     * The Amazon Resource Name (ARN) of the subnet group.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * An optional description of the subnet group.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The name of the subnet group. This value must be unique as it also serves as the subnet group identifier.
     */
    readonly subnetGroupName: pulumi.Output<string>;
    /**
     * A list of VPC subnet IDs for the subnet group.
     */
    readonly subnetIds: pulumi.Output<string[]>;
    /**
     * Supported network types would be a list of network types supported by subnet group and can be either [ipv4] or [ipv4, dual_stack] or [ipv6].
     */
    readonly supportedNetworkTypes: pulumi.Output<string[]>;
    /**
     * An array of key-value pairs to apply to this subnet group.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a SubnetGroup resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: SubnetGroupArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a SubnetGroup resource.
 */
export interface SubnetGroupArgs {
    /**
     * An optional description of the subnet group.
     */
    description?: pulumi.Input<string>;
    /**
     * The name of the subnet group. This value must be unique as it also serves as the subnet group identifier.
     */
    subnetGroupName?: pulumi.Input<string>;
    /**
     * A list of VPC subnet IDs for the subnet group.
     */
    subnetIds: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * An array of key-value pairs to apply to this subnet group.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
