import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * The AWS::NeptuneGraph::Graph resource creates an Amazon NeptuneGraph Graph.
 */
export declare function getGraph(args: GetGraphArgs, opts?: pulumi.InvokeOptions): Promise<GetGraphResult>;
export interface GetGraphArgs {
    /**
     * The auto-generated id assigned by the service.
     */
    graphId: string;
}
export interface GetGraphResult {
    /**
     * Value that indicates whether the Graph has deletion protection enabled. The graph can't be deleted when deletion protection is enabled.
     *
     * _Default_: If not specified, the default value is true.
     */
    readonly deletionProtection?: boolean;
    /**
     * The connection endpoint for the graph. For example: `g-12a3bcdef4.us-east-1.neptune-graph.amazonaws.com`
     */
    readonly endpoint?: string;
    /**
     * Graph resource ARN
     */
    readonly graphArn?: string;
    /**
     * The auto-generated id assigned by the service.
     */
    readonly graphId?: string;
    /**
     * Memory for the Graph.
     */
    readonly provisionedMemory?: number;
    /**
     * Specifies whether the Graph can be reached over the internet. Access to all graphs requires IAM authentication.
     *
     * When the Graph is publicly reachable, its Domain Name System (DNS) endpoint resolves to the public IP address from the internet.
     *
     * When the Graph isn't publicly reachable, you need to create a PrivateGraphEndpoint in a given VPC to ensure the DNS name resolves to a private IP address that is reachable from the VPC.
     *
     * _Default_: If not specified, the default value is false.
     */
    readonly publicConnectivity?: boolean;
    /**
     * The tags associated with this graph.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * The AWS::NeptuneGraph::Graph resource creates an Amazon NeptuneGraph Graph.
 */
export declare function getGraphOutput(args: GetGraphOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetGraphResult>;
export interface GetGraphOutputArgs {
    /**
     * The auto-generated id assigned by the service.
     */
    graphId: pulumi.Input<string>;
}
