import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource type definition for AWS::NetworkFirewall::FirewallPolicy
 */
export declare function getFirewallPolicy(args: GetFirewallPolicyArgs, opts?: pulumi.InvokeOptions): Promise<GetFirewallPolicyResult>;
export interface GetFirewallPolicyArgs {
    /**
     * The Amazon Resource Name (ARN) of the `FirewallPolicy` .
     */
    firewallPolicyArn: string;
}
export interface GetFirewallPolicyResult {
    /**
     * A description of the firewall policy.
     */
    readonly description?: string;
    /**
     * The traffic filtering behavior of a firewall policy, defined in a collection of stateless and stateful rule groups and other settings.
     */
    readonly firewallPolicy?: outputs.networkfirewall.FirewallPolicy;
    /**
     * The Amazon Resource Name (ARN) of the `FirewallPolicy` .
     */
    readonly firewallPolicyArn?: string;
    /**
     * The unique ID of the `FirewallPolicy` resource.
     */
    readonly firewallPolicyId?: string;
    /**
     * An array of key-value pairs to apply to this resource.
     *
     * For more information, see [Tag](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resource-tags.html) .
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Resource type definition for AWS::NetworkFirewall::FirewallPolicy
 */
export declare function getFirewallPolicyOutput(args: GetFirewallPolicyOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetFirewallPolicyResult>;
export interface GetFirewallPolicyOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the `FirewallPolicy` .
     */
    firewallPolicyArn: pulumi.Input<string>;
}
