import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * AWS::PCS::Queue resource creates an AWS PCS queue.
 */
export declare function getQueue(args: GetQueueArgs, opts?: pulumi.InvokeOptions): Promise<GetQueueResult>;
export interface GetQueueArgs {
    /**
     * The unique Amazon Resource Name (ARN) of the queue.
     */
    arn: string;
}
export interface GetQueueResult {
    /**
     * The unique Amazon Resource Name (ARN) of the queue.
     */
    readonly arn?: string;
    /**
     * The list of compute node group configurations associated with the queue. Queues assign jobs to associated compute node groups.
     */
    readonly computeNodeGroupConfigurations?: outputs.pcs.QueueComputeNodeGroupConfiguration[];
    /**
     * The list of errors that occurred during queue provisioning.
     */
    readonly errorInfo?: outputs.pcs.QueueErrorInfo[];
    /**
     * The generated unique ID of the queue.
     */
    readonly id?: string;
    /**
     * The provisioning status of the queue. The provisioning status doesn't indicate the overall health of the queue.
     */
    readonly status?: enums.pcs.QueueStatus;
    /**
     * 1 or more tags added to the resource. Each tag consists of a tag key and tag value. The tag value is optional and can be an empty string.
     */
    readonly tags?: {
        [key: string]: string;
    };
}
/**
 * AWS::PCS::Queue resource creates an AWS PCS queue.
 */
export declare function getQueueOutput(args: GetQueueOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetQueueResult>;
export interface GetQueueOutputArgs {
    /**
     * The unique Amazon Resource Name (ARN) of the queue.
     */
    arn: pulumi.Input<string>;
}
