import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Definition of AWS::Pipes::Pipe Resource Type
 */
export declare function getPipe(args: GetPipeArgs, opts?: pulumi.InvokeOptions): Promise<GetPipeResult>;
export interface GetPipeArgs {
    /**
     * The name of the pipe.
     */
    name: string;
}
export interface GetPipeResult {
    /**
     * The ARN of the pipe.
     */
    readonly arn?: string;
    /**
     * The time the pipe was created.
     */
    readonly creationTime?: string;
    /**
     * The state the pipe is in.
     */
    readonly currentState?: enums.pipes.PipeState;
    /**
     * A description of the pipe.
     */
    readonly description?: string;
    /**
     * The state the pipe should be in.
     */
    readonly desiredState?: enums.pipes.PipeRequestedPipeState;
    /**
     * The ARN of the enrichment resource.
     */
    readonly enrichment?: string;
    /**
     * The parameters required to set up enrichment on your pipe.
     */
    readonly enrichmentParameters?: outputs.pipes.PipeEnrichmentParameters;
    /**
     * The identifier of the AWS KMS customer managed key for EventBridge to use, if you choose to use a customer managed key to encrypt pipe data. The identifier can be the key Amazon Resource Name (ARN), KeyId, key alias, or key alias ARN.
     *
     * To update a pipe that is using the default AWS owned key to use a customer managed key instead, or update a pipe that is using a customer managed key to use a different customer managed key, specify a customer managed key identifier.
     *
     * To update a pipe that is using a customer managed key to use the default AWS owned key , specify an empty string.
     *
     * For more information, see [Managing keys](https://docs.aws.amazon.com/kms/latest/developerguide/getting-started.html) in the *AWS Key Management Service Developer Guide* .
     */
    readonly kmsKeyIdentifier?: string;
    /**
     * When the pipe was last updated, in [ISO-8601 format](https://docs.aws.amazon.com/https://www.w3.org/TR/NOTE-datetime) (YYYY-MM-DDThh:mm:ss.sTZD).
     */
    readonly lastModifiedTime?: string;
    /**
     * The logging configuration settings for the pipe.
     */
    readonly logConfiguration?: outputs.pipes.PipeLogConfiguration;
    /**
     * The ARN of the role that allows the pipe to send data to the target.
     */
    readonly roleArn?: string;
    /**
     * The reason the pipe is in its current state.
     */
    readonly stateReason?: string;
    /**
     * The list of key-value pairs to associate with the pipe.
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * The ARN of the target resource.
     */
    readonly target?: string;
}
/**
 * Definition of AWS::Pipes::Pipe Resource Type
 */
export declare function getPipeOutput(args: GetPipeOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetPipeResult>;
export interface GetPipeOutputArgs {
    /**
     * The name of the pipe.
     */
    name: pulumi.Input<string>;
}
