import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Definition of AWS::QBusiness::Retriever Resource Type
 */
export declare class Retriever extends pulumi.CustomResource {
    /**
     * Get an existing Retriever resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Retriever;
    /**
     * Returns true if the given object is an instance of Retriever.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Retriever;
    /**
     * The identifier of the Amazon Q Business application using the retriever.
     */
    readonly applicationId: pulumi.Output<string>;
    /**
     * Provides information on how the retriever used for your Amazon Q Business application is configured.
     */
    readonly configuration: pulumi.Output<outputs.qbusiness.RetrieverConfiguration0Properties | outputs.qbusiness.RetrieverConfiguration1Properties>;
    /**
     * The Unix timestamp when the retriever was created.
     */
    readonly createdAt: pulumi.Output<string>;
    /**
     * The name of your retriever.
     */
    readonly displayName: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of the IAM role associated with the retriever.
     */
    readonly retrieverArn: pulumi.Output<string>;
    /**
     * The identifier of the retriever used by your Amazon Q Business application.
     */
    readonly retrieverId: pulumi.Output<string>;
    /**
     * The ARN of an IAM role used by Amazon Q Business to access the basic authentication credentials stored in a Secrets Manager secret.
     */
    readonly roleArn: pulumi.Output<string | undefined>;
    /**
     * The status of your retriever.
     */
    readonly status: pulumi.Output<enums.qbusiness.RetrieverStatus>;
    /**
     * A list of key-value pairs that identify or categorize the retriever. You can also use tags to help control access to the retriever. Tag keys and values can consist of Unicode letters, digits, white space, and any of the following symbols: _ . : / = + - @.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The type of your retriever.
     */
    readonly type: pulumi.Output<enums.qbusiness.RetrieverType>;
    /**
     * The Unix timestamp when the retriever was last updated.
     */
    readonly updatedAt: pulumi.Output<string>;
    /**
     * Create a Retriever resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: RetrieverArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Retriever resource.
 */
export interface RetrieverArgs {
    /**
     * The identifier of the Amazon Q Business application using the retriever.
     */
    applicationId: pulumi.Input<string>;
    /**
     * Provides information on how the retriever used for your Amazon Q Business application is configured.
     */
    configuration: pulumi.Input<inputs.qbusiness.RetrieverConfiguration0PropertiesArgs | inputs.qbusiness.RetrieverConfiguration1PropertiesArgs>;
    /**
     * The name of your retriever.
     */
    displayName: pulumi.Input<string>;
    /**
     * The ARN of an IAM role used by Amazon Q Business to access the basic authentication credentials stored in a Secrets Manager secret.
     */
    roleArn?: pulumi.Input<string>;
    /**
     * A list of key-value pairs that identify or categorize the retriever. You can also use tags to help control access to the retriever. Tag keys and values can consist of Unicode letters, digits, white space, and any of the following symbols: _ . : / = + - @.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The type of your retriever.
     */
    type: pulumi.Input<enums.qbusiness.RetrieverType>;
}
