import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource schema for AWS::QLDB::Stream.
 */
export declare function getStream(args: GetStreamArgs, opts?: pulumi.InvokeOptions): Promise<GetStreamResult>;
export interface GetStreamArgs {
    /**
     * The unique ID that QLDB assigns to each QLDB journal stream. For example: `IiPT4brpZCqCq3f4MTHbYy` .
     */
    id: string;
    /**
     * The name of the ledger.
     */
    ledgerName: string;
}
export interface GetStreamResult {
    /**
     * The Amazon Resource Name (ARN) of the QLDB journal stream. For example: `arn:aws:qldb:us-east-1:123456789012:stream/exampleLedger/IiPT4brpZCqCq3f4MTHbYy` .
     */
    readonly arn?: string;
    /**
     * The unique ID that QLDB assigns to each QLDB journal stream. For example: `IiPT4brpZCqCq3f4MTHbYy` .
     */
    readonly id?: string;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Resource schema for AWS::QLDB::Stream.
 */
export declare function getStreamOutput(args: GetStreamOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetStreamResult>;
export interface GetStreamOutputArgs {
    /**
     * The unique ID that QLDB assigns to each QLDB journal stream. For example: `IiPT4brpZCqCq3f4MTHbYy` .
     */
    id: pulumi.Input<string>;
    /**
     * The name of the ledger.
     */
    ledgerName: pulumi.Input<string>;
}
