import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource schema for AWS::RDS::DBProxyEndpoint.
 */
export declare class DbProxyEndpoint extends pulumi.CustomResource {
    /**
     * Get an existing DbProxyEndpoint resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): DbProxyEndpoint;
    /**
     * Returns true if the given object is an instance of DbProxyEndpoint.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is DbProxyEndpoint;
    /**
     * The Amazon Resource Name (ARN) for the DB proxy endpoint.
     */
    readonly dbProxyEndpointArn: pulumi.Output<string>;
    /**
     * The identifier for the DB proxy endpoint. This name must be unique for all DB proxy endpoints owned by your AWS account in the specified AWS Region.
     */
    readonly dbProxyEndpointName: pulumi.Output<string>;
    /**
     * The identifier for the proxy. This name must be unique for all proxies owned by your AWS account in the specified AWS Region.
     */
    readonly dbProxyName: pulumi.Output<string>;
    /**
     * The endpoint that you can use to connect to the DB proxy. You include the endpoint value in the connection string for a database client application.
     */
    readonly endpoint: pulumi.Output<string>;
    /**
     * A value that indicates whether this endpoint is the default endpoint for the associated DB proxy. Default DB proxy endpoints always have read/write capability. Other endpoints that you associate with the DB proxy can be either read/write or read-only.
     */
    readonly isDefault: pulumi.Output<boolean>;
    /**
     * An optional set of key-value pairs to associate arbitrary data of your choosing with the DB proxy endpoint.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * A value that indicates whether the DB proxy endpoint can be used for read/write or read-only operations.
     */
    readonly targetRole: pulumi.Output<enums.rds.DbProxyEndpointTargetRole | undefined>;
    /**
     * VPC ID to associate with the new DB proxy endpoint.
     */
    readonly vpcId: pulumi.Output<string>;
    /**
     * VPC security group IDs to associate with the new DB proxy endpoint.
     */
    readonly vpcSecurityGroupIds: pulumi.Output<string[] | undefined>;
    /**
     * VPC subnet IDs to associate with the new DB proxy endpoint.
     */
    readonly vpcSubnetIds: pulumi.Output<string[]>;
    /**
     * Create a DbProxyEndpoint resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: DbProxyEndpointArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a DbProxyEndpoint resource.
 */
export interface DbProxyEndpointArgs {
    /**
     * The identifier for the DB proxy endpoint. This name must be unique for all DB proxy endpoints owned by your AWS account in the specified AWS Region.
     */
    dbProxyEndpointName?: pulumi.Input<string>;
    /**
     * The identifier for the proxy. This name must be unique for all proxies owned by your AWS account in the specified AWS Region.
     */
    dbProxyName: pulumi.Input<string>;
    /**
     * An optional set of key-value pairs to associate arbitrary data of your choosing with the DB proxy endpoint.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * A value that indicates whether the DB proxy endpoint can be used for read/write or read-only operations.
     */
    targetRole?: pulumi.Input<enums.rds.DbProxyEndpointTargetRole>;
    /**
     * VPC security group IDs to associate with the new DB proxy endpoint.
     */
    vpcSecurityGroupIds?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * VPC subnet IDs to associate with the new DB proxy endpoint.
     */
    vpcSubnetIds: pulumi.Input<pulumi.Input<string>[]>;
}
