import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource schema for AWS::Route53Resolver::FirewallRuleGroup.
 */
export declare class FirewallRuleGroup extends pulumi.CustomResource {
    /**
     * Get an existing FirewallRuleGroup resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): FirewallRuleGroup;
    /**
     * Returns true if the given object is an instance of FirewallRuleGroup.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is FirewallRuleGroup;
    /**
     * Arn
     */
    readonly arn: pulumi.Output<string>;
    /**
     * ResourceId
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * Rfc3339TimeString
     */
    readonly creationTime: pulumi.Output<string>;
    /**
     * The id of the creator request.
     */
    readonly creatorRequestId: pulumi.Output<string>;
    /**
     * FirewallRules
     */
    readonly firewallRules: pulumi.Output<outputs.route53resolver.FirewallRuleGroupFirewallRule[] | undefined>;
    /**
     * Rfc3339TimeString
     */
    readonly modificationTime: pulumi.Output<string>;
    /**
     * FirewallRuleGroupName
     */
    readonly name: pulumi.Output<string | undefined>;
    /**
     * AccountId
     */
    readonly ownerId: pulumi.Output<string>;
    /**
     * Count
     */
    readonly ruleCount: pulumi.Output<number>;
    /**
     * ShareStatus, possible values are NOT_SHARED, SHARED_WITH_ME, SHARED_BY_ME.
     */
    readonly shareStatus: pulumi.Output<enums.route53resolver.FirewallRuleGroupShareStatus>;
    /**
     * ResolverFirewallRuleGroupAssociation, possible values are COMPLETE, DELETING, UPDATING, and INACTIVE_OWNER_ACCOUNT_CLOSED.
     */
    readonly status: pulumi.Output<enums.route53resolver.FirewallRuleGroupStatus>;
    /**
     * FirewallRuleGroupStatus
     */
    readonly statusMessage: pulumi.Output<string>;
    /**
     * Tags
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a FirewallRuleGroup resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: FirewallRuleGroupArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a FirewallRuleGroup resource.
 */
export interface FirewallRuleGroupArgs {
    /**
     * FirewallRules
     */
    firewallRules?: pulumi.Input<pulumi.Input<inputs.route53resolver.FirewallRuleGroupFirewallRuleArgs>[]>;
    /**
     * FirewallRuleGroupName
     */
    name?: pulumi.Input<string>;
    /**
     * Tags
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
