import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * The policy to be attached to a Multi Region Access Point
 */
export declare class MultiRegionAccessPointPolicy extends pulumi.CustomResource {
    /**
     * Get an existing MultiRegionAccessPointPolicy resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): MultiRegionAccessPointPolicy;
    /**
     * Returns true if the given object is an instance of MultiRegionAccessPointPolicy.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is MultiRegionAccessPointPolicy;
    /**
     * The name of the Multi Region Access Point to apply policy
     */
    readonly mrapName: pulumi.Output<string>;
    /**
     * Policy document to apply to a Multi Region Access Point
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::S3::MultiRegionAccessPointPolicy` for more information about the expected schema for this property.
     */
    readonly policy: pulumi.Output<any>;
    /**
     * The Policy Status associated with this Multi Region Access Point
     */
    readonly policyStatus: pulumi.Output<outputs.s3.PolicyStatusProperties>;
    /**
     * Create a MultiRegionAccessPointPolicy resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: MultiRegionAccessPointPolicyArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a MultiRegionAccessPointPolicy resource.
 */
export interface MultiRegionAccessPointPolicyArgs {
    /**
     * The name of the Multi Region Access Point to apply policy
     */
    mrapName: pulumi.Input<string>;
    /**
     * Policy document to apply to a Multi Region Access Point
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::S3::MultiRegionAccessPointPolicy` for more information about the expected schema for this property.
     */
    policy: any;
}
