import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::SageMaker::MlflowTrackingServer
 */
export declare function getMlflowTrackingServer(args: GetMlflowTrackingServerArgs, opts?: pulumi.InvokeOptions): Promise<GetMlflowTrackingServerResult>;
export interface GetMlflowTrackingServerArgs {
    /**
     * The name of the MLFlow Tracking Server.
     */
    trackingServerName: string;
}
export interface GetMlflowTrackingServerResult {
    /**
     * The Amazon S3 URI for MLFlow Tracking Server artifacts.
     */
    readonly artifactStoreUri?: string;
    /**
     * A flag to enable Automatic SageMaker Model Registration.
     */
    readonly automaticModelRegistration?: boolean;
    /**
     * The MLFlow Version used on the MLFlow Tracking Server.
     */
    readonly mlflowVersion?: string;
    /**
     * The Amazon Resource Name (ARN) of an IAM role that enables Amazon SageMaker to perform tasks on behalf of the customer.
     */
    readonly roleArn?: string;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags?: outputs.Tag[];
    /**
     * The Amazon Resource Name (ARN) of the MLFlow Tracking Server.
     */
    readonly trackingServerArn?: string;
    /**
     * The size of the MLFlow Tracking Server.
     */
    readonly trackingServerSize?: enums.sagemaker.MlflowTrackingServerTrackingServerSize;
    /**
     * The start of the time window for maintenance of the MLFlow Tracking Server in UTC time.
     */
    readonly weeklyMaintenanceWindowStart?: string;
}
/**
 * Resource Type definition for AWS::SageMaker::MlflowTrackingServer
 */
export declare function getMlflowTrackingServerOutput(args: GetMlflowTrackingServerOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetMlflowTrackingServerResult>;
export interface GetMlflowTrackingServerOutputArgs {
    /**
     * The name of the MLFlow Tracking Server.
     */
    trackingServerName: pulumi.Input<string>;
}
