import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Definition of AWS::Scheduler::ScheduleGroup Resource Type
 */
export declare class ScheduleGroup extends pulumi.CustomResource {
    /**
     * Get an existing ScheduleGroup resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ScheduleGroup;
    /**
     * Returns true if the given object is an instance of ScheduleGroup.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ScheduleGroup;
    /**
     * The Amazon Resource Name (ARN) of the schedule group.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The time at which the schedule group was created.
     */
    readonly creationDate: pulumi.Output<string>;
    /**
     * The time at which the schedule group was last modified.
     */
    readonly lastModificationDate: pulumi.Output<string>;
    /**
     * The name of the schedule group.
     */
    readonly name: pulumi.Output<string | undefined>;
    /**
     * Specifies the state of the schedule group.
     *
     * *Allowed Values* : `ACTIVE` | `DELETING`
     */
    readonly state: pulumi.Output<enums.scheduler.ScheduleGroupState>;
    /**
     * The list of tags to associate with the schedule group.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a ScheduleGroup resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: ScheduleGroupArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ScheduleGroup resource.
 */
export interface ScheduleGroupArgs {
    /**
     * The name of the schedule group.
     */
    name?: pulumi.Input<string>;
    /**
     * The list of tags to associate with the schedule group.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
