import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * A security control in Security Hub describes a security best practice related to a specific resource.
 */
export declare function getSecurityControl(args: GetSecurityControlArgs, opts?: pulumi.InvokeOptions): Promise<GetSecurityControlResult>;
export interface GetSecurityControlArgs {
    /**
     * The unique identifier of a security control across standards. Values for this field typically consist of an AWS service name and a number, such as APIGateway.3.
     */
    securityControlId: string;
}
export interface GetSecurityControlResult {
    /**
     * The most recent reason for updating the customizable properties of a security control. This differs from the UpdateReason field of the BatchUpdateStandardsControlAssociations API, which tracks the reason for updating the enablement status of a control. This field accepts alphanumeric characters in addition to white spaces, dashes, and underscores.
     */
    readonly lastUpdateReason?: string;
    /**
     * An object that identifies the name of a control parameter, its current value, and whether it has been customized.
     */
    readonly parameters?: {
        [key: string]: outputs.securityhub.SecurityControlParameterConfiguration;
    };
    /**
     * The Amazon Resource Name (ARN) for a security control across standards, such as `arn:aws:securityhub:eu-central-1:123456789012:security-control/S3.1`. This parameter doesn't mention a specific standard.
     */
    readonly securityControlArn?: string;
}
/**
 * A security control in Security Hub describes a security best practice related to a specific resource.
 */
export declare function getSecurityControlOutput(args: GetSecurityControlOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetSecurityControlResult>;
export interface GetSecurityControlOutputArgs {
    /**
     * The unique identifier of a security control across standards. Values for this field typically consist of an AWS service name and a number, such as APIGateway.3.
     */
    securityControlId: pulumi.Input<string>;
}
