import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Schema for AWS::ServiceCatalog::CloudFormationProvisionedProduct
 */
export declare function getCloudFormationProvisionedProduct(args: GetCloudFormationProvisionedProductArgs, opts?: pulumi.InvokeOptions): Promise<GetCloudFormationProvisionedProductResult>;
export interface GetCloudFormationProvisionedProductArgs {
    /**
     * The ID of the provisioned product.
     */
    provisionedProductId: string;
}
export interface GetCloudFormationProvisionedProductResult {
    /**
     * The language code.
     *
     * - `jp` - Japanese
     * - `zh` - Chinese
     */
    readonly acceptLanguage?: enums.servicecatalog.CloudFormationProvisionedProductAcceptLanguage;
    readonly cloudformationStackArn?: string;
    /**
     * List of key-value pair outputs.
     */
    readonly outputs?: {
        [key: string]: string;
    };
    /**
     * The path identifier of the product. This value is optional if the product has a default path, and required if the product has more than one path. To list the paths for a product, use [ListLaunchPaths](https://docs.aws.amazon.com/servicecatalog/latest/dg/API_ListLaunchPaths.html) .
     *
     * > You must provide the name or ID, but not both.
     */
    readonly pathId?: string;
    /**
     * The name of the path. This value is optional if the product has a default path, and required if the product has more than one path. To list the paths for a product, use [ListLaunchPaths](https://docs.aws.amazon.com/servicecatalog/latest/dg/API_ListLaunchPaths.html) .
     *
     * > You must provide the name or ID, but not both.
     */
    readonly pathName?: string;
    /**
     * The product identifier.
     *
     * > You must specify either the ID or the name of the product, but not both.
     */
    readonly productId?: string;
    /**
     * The name of the Service Catalog product.
     *
     * Each time a stack is created or updated, if `ProductName` is provided it will successfully resolve to `ProductId` as long as only one product exists in the account or Region with that `ProductName` .
     *
     * > You must specify either the name or the ID of the product, but not both.
     */
    readonly productName?: string;
    /**
     * The ID of the provisioned product.
     */
    readonly provisionedProductId?: string;
    /**
     * The identifier of the provisioning artifact (also known as a version).
     *
     * > You must specify either the ID or the name of the provisioning artifact, but not both.
     */
    readonly provisioningArtifactId?: string;
    /**
     * The name of the provisioning artifact (also known as a version) for the product. This name must be unique for the product.
     *
     * > You must specify either the name or the ID of the provisioning artifact, but not both. You must also specify either the name or the ID of the product, but not both.
     */
    readonly provisioningArtifactName?: string;
    /**
     * Parameters specified by the administrator that are required for provisioning the product.
     */
    readonly provisioningParameters?: outputs.servicecatalog.CloudFormationProvisionedProductProvisioningParameter[];
    /**
     * StackSet preferences that are required for provisioning the product or updating a provisioned product.
     */
    readonly provisioningPreferences?: outputs.servicecatalog.CloudFormationProvisionedProductProvisioningPreferences;
    /**
     * The ID of the record, such as `rec-rjeatvy434trk` .
     */
    readonly recordId?: string;
    /**
     * One or more tags.
     *
     * > Requires the provisioned product to have an [ResourceUpdateConstraint](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-resourceupdateconstraint.html) resource with `TagUpdatesOnProvisionedProduct` set to `ALLOWED` to allow tag updates. If `RESOURCE_UPDATE` constraint is not present, tags updates are ignored.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Resource Schema for AWS::ServiceCatalog::CloudFormationProvisionedProduct
 */
export declare function getCloudFormationProvisionedProductOutput(args: GetCloudFormationProvisionedProductOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetCloudFormationProvisionedProductResult>;
export interface GetCloudFormationProvisionedProductOutputArgs {
    /**
     * The ID of the provisioned product.
     */
    provisionedProductId: pulumi.Input<string>;
}
