import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Schema for AWS::ServiceCatalog::ServiceAction
 */
export declare class ServiceAction extends pulumi.CustomResource {
    /**
     * Get an existing ServiceAction resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ServiceAction;
    /**
     * Returns true if the given object is an instance of ServiceAction.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ServiceAction;
    /**
     * The language code.
     *
     * - `en` - English (default)
     * - `jp` - Japanese
     * - `zh` - Chinese
     */
    readonly acceptLanguage: pulumi.Output<enums.servicecatalog.ServiceActionAcceptLanguage | undefined>;
    /**
     * The self-service action identifier. For example, `act-fs7abcd89wxyz` .
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * A map that defines the self-service action.
     */
    readonly definition: pulumi.Output<outputs.servicecatalog.ServiceActionDefinitionParameter[]>;
    /**
     * The self-service action definition type. For example, `SSM_AUTOMATION` .
     */
    readonly definitionType: pulumi.Output<enums.servicecatalog.ServiceActionDefinitionType>;
    /**
     * The self-service action description.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The self-service action name.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Create a ServiceAction resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ServiceActionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ServiceAction resource.
 */
export interface ServiceActionArgs {
    /**
     * The language code.
     *
     * - `en` - English (default)
     * - `jp` - Japanese
     * - `zh` - Chinese
     */
    acceptLanguage?: pulumi.Input<enums.servicecatalog.ServiceActionAcceptLanguage>;
    /**
     * A map that defines the self-service action.
     */
    definition: pulumi.Input<pulumi.Input<inputs.servicecatalog.ServiceActionDefinitionParameterArgs>[]>;
    /**
     * The self-service action definition type. For example, `SSM_AUTOMATION` .
     */
    definitionType: pulumi.Input<enums.servicecatalog.ServiceActionDefinitionType>;
    /**
     * The self-service action description.
     */
    description?: pulumi.Input<string>;
    /**
     * The self-service action name.
     */
    name?: pulumi.Input<string>;
}
