import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Authorizes the Shield Response Team (SRT) to use email and phone to notify contacts about escalations to the SRT and to initiate proactive customer support.
 */
export declare function getProactiveEngagement(args: GetProactiveEngagementArgs, opts?: pulumi.InvokeOptions): Promise<GetProactiveEngagementResult>;
export interface GetProactiveEngagementArgs {
    /**
     * The ID of the account that submitted the template.
     */
    accountId: string;
}
export interface GetProactiveEngagementResult {
    /**
     * The ID of the account that submitted the template.
     */
    readonly accountId?: string;
    /**
     * A list of email addresses and phone numbers that the Shield Response Team (SRT) can use to contact you for escalations to the SRT and to initiate proactive customer support.
     * To enable proactive engagement, the contact list must include at least one phone number.
     */
    readonly emergencyContactList?: outputs.shield.ProactiveEngagementEmergencyContact[];
    /**
     * If `ENABLED`, the Shield Response Team (SRT) will use email and phone to notify contacts about escalations to the SRT and to initiate proactive customer support.
     * If `DISABLED`, the SRT will not proactively notify contacts about escalations or to initiate proactive customer support.
     */
    readonly proactiveEngagementStatus?: enums.shield.ProactiveEngagementStatus;
}
/**
 * Authorizes the Shield Response Team (SRT) to use email and phone to notify contacts about escalations to the SRT and to initiate proactive customer support.
 */
export declare function getProactiveEngagementOutput(args: GetProactiveEngagementOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetProactiveEngagementResult>;
export interface GetProactiveEngagementOutputArgs {
    /**
     * The ID of the account that submitted the template.
     */
    accountId: pulumi.Input<string>;
}
