import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Enables AWS Shield Advanced for a specific AWS resource. The resource can be an Amazon CloudFront distribution, Amazon Route 53 hosted zone, AWS Global Accelerator standard accelerator, Elastic IP Address, Application Load Balancer, or a Classic Load Balancer. You can protect Amazon EC2 instances and Network Load Balancers by association with protected Amazon EC2 Elastic IP addresses.
 */
export declare function getProtection(args: GetProtectionArgs, opts?: pulumi.InvokeOptions): Promise<GetProtectionResult>;
export interface GetProtectionArgs {
    /**
     * The ARN (Amazon Resource Name) of the protection.
     */
    protectionArn: string;
}
export interface GetProtectionResult {
    /**
     * The automatic application layer DDoS mitigation settings for the protection. This configuration determines whether Shield Advanced automatically manages rules in the web ACL in order to respond to application layer events that Shield Advanced determines to be DDoS attacks.
     *
     * If you use AWS CloudFormation to manage the web ACLs that you use with Shield Advanced automatic mitigation, see the additional guidance about web ACL management in the `AWS::WAFv2::WebACL` resource description.
     */
    readonly applicationLayerAutomaticResponseConfiguration?: outputs.shield.ProtectionApplicationLayerAutomaticResponseConfiguration;
    /**
     * The Amazon Resource Names (ARNs) of the health check to associate with the protection.
     */
    readonly healthCheckArns?: string[];
    /**
     * The ARN (Amazon Resource Name) of the protection.
     */
    readonly protectionArn?: string;
    /**
     * The unique identifier (ID) of the protection.
     */
    readonly protectionId?: string;
    /**
     * One or more tag key-value pairs for the Protection object.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Enables AWS Shield Advanced for a specific AWS resource. The resource can be an Amazon CloudFront distribution, Amazon Route 53 hosted zone, AWS Global Accelerator standard accelerator, Elastic IP Address, Application Load Balancer, or a Classic Load Balancer. You can protect Amazon EC2 instances and Network Load Balancers by association with protected Amazon EC2 Elastic IP addresses.
 */
export declare function getProtectionOutput(args: GetProtectionOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetProtectionResult>;
export interface GetProtectionOutputArgs {
    /**
     * The ARN (Amazon Resource Name) of the protection.
     */
    protectionArn: pulumi.Input<string>;
}
