import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::SSMContacts::Rotation.
 */
export declare function getRotation(args: GetRotationArgs, opts?: pulumi.InvokeOptions): Promise<GetRotationResult>;
export interface GetRotationArgs {
    /**
     * The Amazon Resource Name (ARN) of the rotation.
     */
    arn: string;
}
export interface GetRotationResult {
    /**
     * The Amazon Resource Name (ARN) of the rotation.
     */
    readonly arn?: string;
    /**
     * Members of the rotation
     */
    readonly contactIds?: string[];
    /**
     * Name of the Rotation
     */
    readonly name?: string;
    /**
     * Information about the rule that specifies when shift team members rotate.
     */
    readonly recurrence?: outputs.ssmcontacts.RotationRecurrenceSettings;
    /**
     * Start time of the first shift of Oncall Schedule
     */
    readonly startTime?: string;
    /**
     * Optional metadata to assign to the rotation. Tags enable you to categorize a resource in different ways, such as by purpose, owner, or environment. For more information, see [Tagging Incident Manager resources](https://docs.aws.amazon.com/incident-manager/latest/userguide/tagging.html) in the *Incident Manager User Guide* .
     */
    readonly tags?: outputs.Tag[];
    /**
     * TimeZone Identifier for the Oncall Schedule
     */
    readonly timeZoneId?: string;
}
/**
 * Resource Type definition for AWS::SSMContacts::Rotation.
 */
export declare function getRotationOutput(args: GetRotationOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetRotationResult>;
export interface GetRotationOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the rotation.
     */
    arn: pulumi.Input<string>;
}
