import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::SSMContacts::Rotation.
 */
export declare class Rotation extends pulumi.CustomResource {
    /**
     * Get an existing Rotation resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Rotation;
    /**
     * Returns true if the given object is an instance of Rotation.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Rotation;
    /**
     * The Amazon Resource Name (ARN) of the rotation.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Members of the rotation
     */
    readonly contactIds: pulumi.Output<string[]>;
    /**
     * Name of the Rotation
     */
    readonly name: pulumi.Output<string>;
    /**
     * Information about the rule that specifies when shift team members rotate.
     */
    readonly recurrence: pulumi.Output<outputs.ssmcontacts.RotationRecurrenceSettings>;
    /**
     * Start time of the first shift of Oncall Schedule
     */
    readonly startTime: pulumi.Output<string>;
    /**
     * Optional metadata to assign to the rotation. Tags enable you to categorize a resource in different ways, such as by purpose, owner, or environment. For more information, see [Tagging Incident Manager resources](https://docs.aws.amazon.com/incident-manager/latest/userguide/tagging.html) in the *Incident Manager User Guide* .
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * TimeZone Identifier for the Oncall Schedule
     */
    readonly timeZoneId: pulumi.Output<string>;
    /**
     * Create a Rotation resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: RotationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Rotation resource.
 */
export interface RotationArgs {
    /**
     * Members of the rotation
     */
    contactIds: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Name of the Rotation
     */
    name?: pulumi.Input<string>;
    /**
     * Information about the rule that specifies when shift team members rotate.
     */
    recurrence: pulumi.Input<inputs.ssmcontacts.RotationRecurrenceSettingsArgs>;
    /**
     * Start time of the first shift of Oncall Schedule
     */
    startTime: pulumi.Input<string>;
    /**
     * Optional metadata to assign to the rotation. Tags enable you to categorize a resource in different ways, such as by purpose, owner, or environment. For more information, see [Tagging Incident Manager resources](https://docs.aws.amazon.com/incident-manager/latest/userguide/tagging.html) in the *Incident Manager User Guide* .
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * TimeZone Identifier for the Oncall Schedule
     */
    timeZoneId: pulumi.Input<string>;
}
