import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Definition of AWS::VerifiedPermissions::IdentitySource Resource Type
 */
export declare function getIdentitySource(args: GetIdentitySourceArgs, opts?: pulumi.InvokeOptions): Promise<GetIdentitySourceResult>;
export interface GetIdentitySourceArgs {
    /**
     * The unique ID of the new or updated identity store.
     */
    identitySourceId: string;
    /**
     * Specifies the ID of the policy store in which you want to store this identity source. Only policies and requests made using this policy store can reference identities from the identity provider configured in the new identity source.
     */
    policyStoreId: string;
}
export interface GetIdentitySourceResult {
    /**
     * Contains configuration information used when creating a new identity source.
     */
    readonly configuration?: outputs.verifiedpermissions.IdentitySourceConfiguration0Properties | outputs.verifiedpermissions.IdentitySourceConfiguration1Properties;
    readonly details?: outputs.verifiedpermissions.IdentitySourceDetails;
    /**
     * The unique ID of the new or updated identity store.
     */
    readonly identitySourceId?: string;
    /**
     * Specifies the namespace and data type of the principals generated for identities authenticated by the new identity source.
     */
    readonly principalEntityType?: string;
}
/**
 * Definition of AWS::VerifiedPermissions::IdentitySource Resource Type
 */
export declare function getIdentitySourceOutput(args: GetIdentitySourceOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetIdentitySourceResult>;
export interface GetIdentitySourceOutputArgs {
    /**
     * The unique ID of the new or updated identity store.
     */
    identitySourceId: pulumi.Input<string>;
    /**
     * Specifies the ID of the policy store in which you want to store this identity source. Only policies and requests made using this policy store can reference identities from the identity provider configured in the new identity source.
     */
    policyStoreId: pulumi.Input<string>;
}
